@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 
 static const QString longOpt("compose");
 
+static const QString senderStr("sender");
 static const QString dbIDRecipientStr("dbIDRecipient");
 static const QString dmAnnotationStr("dmAnnotation");
 static const QString dmToHandsStr("dmToHands");
@@ -64,7 +65,7 @@ class CLI::CmdComposePrivate {
 	//Q_DISABLE_COPY(CmdComposePrivate)
 public:
 	CmdComposePrivate(void)
-	    : m_dbIDRecipient(), m_dmAnnotation(), m_dmToHands(),
+	    : m_sender(), m_dbIDRecipient(), m_dmAnnotation(), m_dmToHands(),
 	    m_dmRecipientRefNumber(), m_dmSenderRefNumber(),
 	    m_dmRecipientIdent(), m_dmSenderIdent(), m_dmLegalTitleLaw(-1),
 	    m_dmLegalTitleYear(-1), m_dmLegalTitleSect(), m_dmLegalTitlePar(),
@@ -74,6 +75,7 @@ public:
 	    m_recMgmtUpload(Isds::Type::BOOL_NULL), m_recMgmtHierarchyId()
 	{ }
 
+	QString m_sender;
 	QStringList m_dbIDRecipient;
 	QString m_dmAnnotation;
 	QString m_dmToHands;
@@ -207,12 +209,17 @@ CLI::CmdCompose CLI::CmdCompose::deserialise(const QString &content)
 	CmdCompose cmdCompose;
 
 	typedef QPair<QString, QString> TokenPair;
-	foreach (const TokenPair &pair, opts) {
+	for (const TokenPair &pair : opts) {
 		if (Q_UNLIKELY(pair.second.isEmpty())) {
 			return CmdCompose();
 		}
 
-		if (::dbIDRecipientStr == pair.first) {
+		if (::senderStr == pair.first) {
+			if (!cmdCompose.sender().isEmpty()) {
+				return CmdCompose(); /* Already set. */
+			}
+			cmdCompose.setSender(pair.second);
+		} else if (::dbIDRecipientStr == pair.first) {
 			if (!cmdCompose.dbIDRecipient().isEmpty()) {
 				return CmdCompose(); /* Already set. */
 			}
@@ -316,6 +323,9 @@ QString CLI::CmdCompose::serialise(void) const
 {
 	QStringList serialised;
 
+	if (!sender().isEmpty()) {
+		serialised.append(::senderStr % QStringLiteral("='") % sender() % QStringLiteral("'"));
+	}
 	if (!dbIDRecipient().isEmpty()) {
 		serialised.append(::dbIDRecipientStr % QStringLiteral("='") % dbIDRecipient().join(QChar(';')) % QStringLiteral("'"));
 	}
@@ -536,6 +546,31 @@ bool CLI::CmdCompose::setRecMgmtUploadStr(const QString &rmu)
 	return iOk;
 }
 
+const QString &CLI::CmdCompose::sender(void) const
+{
+	Q_D(const CmdCompose);
+	if (Q_UNLIKELY(d == Q_NULLPTR)) {
+		return nullString;
+	}
+	return d->m_sender;
+}
+
+void CLI::CmdCompose::setSender(const QString &s)
+{
+	ensureCmdComposePrivate();
+	Q_D(CmdCompose);
+	d->m_sender = s;
+}
+
+#ifdef Q_COMPILER_RVALUE_REFS
+void CLI::CmdCompose::setSender(QString &&s)
+{
+	ensureCmdComposePrivate();
+	Q_D(CmdCompose);
+	d->m_sender = ::std::move(s);
+}
+#endif /* Q_COMPILER_RVALUE_REFS */
+
 const QStringList &CLI::CmdCompose::dbIDRecipient(void) const
 {
 	Q_D(const CmdCompose);
