@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -566,7 +566,7 @@ bool SQLiteDb::backup(const QString &fileName)
 	QSqlDatabase backupDb(
 	    QSqlDatabase::addDatabase(dbDriverType, "BACKUP_FILE_DATABASE"));
 
-	backupDb.setDatabaseName(QDir::toNativeSeparators(fileName));
+	backupDb.setDatabaseName(QDir::fromNativeSeparators(fileName));
 
 	QMutexLocker locker(&m_lock);
 
@@ -858,7 +858,7 @@ bool SQLiteDb::openDb(const QString &fileName, OpenFlags flags)
 	}
 
 	if (!(flags & FORCE_IN_MEMORY)) {
-		m_db.setDatabaseName(QDir::toNativeSeparators(fileName));
+		m_db.setDatabaseName(QDir::fromNativeSeparators(fileName));
 	} else {
 		m_db.setDatabaseName(memoryLocation);
 	}
