@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,6 +33,7 @@ static const Isds::CreditEventCharged nullCreditEventCharged;
 static const Isds::CreditEventDischarged nullCreditEventDischarged;
 static const Isds::CreditEventMsgSent nullCreditEventMsgSent;
 static const Isds::CreditEventStorageSet nullCreditEventStorageSet;
+static const Isds::CreditEventDeletedMessageRecovered nullCreditEventDeletedMessageRecovered;
 static const Isds::PersonName nullPersonName;
 static const QDate nullDate;
 static const QDateTime nullDateTime;
@@ -2862,6 +2863,156 @@ void Isds::swap(CreditEventStorageSet &first, CreditEventStorageSet &second) Q_D
 	swap(first.d_ptr, second.d_ptr);
 }
 
+/*!
+ * @brief PIMPL CreditEventDeletedMessageRecovered class.
+ */
+class Isds::CreditEventDeletedMessageRecoveredPrivate {
+	//Q_DISABLE_COPY(CreditEventDeletedMessageRecoveredPrivate)
+
+public:
+	CreditEventDeletedMessageRecoveredPrivate(void)
+	    : m_initiator()
+	{ }
+
+	CreditEventDeletedMessageRecoveredPrivate &operator=(const CreditEventDeletedMessageRecoveredPrivate &other) Q_DECL_NOTHROW
+	{
+		m_initiator = other.m_initiator;
+
+		return *this;
+	}
+
+	bool operator==(const CreditEventDeletedMessageRecoveredPrivate &other) const
+	{
+		return (m_initiator == other.m_initiator);
+	}
+
+	QString m_initiator; /*!< Name of a user who initiated the change. */
+};
+
+Isds::CreditEventDeletedMessageRecovered::CreditEventDeletedMessageRecovered(void)
+    : d_ptr(Q_NULLPTR)
+{
+}
+
+Isds::CreditEventDeletedMessageRecovered::CreditEventDeletedMessageRecovered(const CreditEventDeletedMessageRecovered &other)
+    : d_ptr((other.d_func() != Q_NULLPTR) ? (new (::std::nothrow) CreditEventDeletedMessageRecoveredPrivate) : Q_NULLPTR)
+{
+	Q_D(CreditEventDeletedMessageRecovered);
+	if (d == Q_NULLPTR) {
+		return;
+	}
+
+	*d = *other.d_func();
+}
+
+#ifdef Q_COMPILER_RVALUE_REFS
+Isds::CreditEventDeletedMessageRecovered::CreditEventDeletedMessageRecovered(CreditEventDeletedMessageRecovered &&other) Q_DECL_NOEXCEPT
+#  if (QT_VERSION >= QT_VERSION_CHECK(5, 12, 0))
+    : d_ptr(other.d_ptr.release()) //d_ptr(::std::move(other.d_ptr))
+#  else /* < Qt-5.12 */
+    : d_ptr(other.d_ptr.take())
+#  endif /* >= Qt-5.12 */
+{
+}
+#endif /* Q_COMPILER_RVALUE_REFS */
+
+Isds::CreditEventDeletedMessageRecovered::~CreditEventDeletedMessageRecovered(void)
+{
+}
+
+/*!
+ * @brief Ensures CreditEventDeletedMessageRecoveredPrivate presence.
+ *
+ * @note Returns if CreditEventDeletedMessageRecoveredPrivate could not be allocated.
+ */
+#define ensureCreditEventDeletedMessageRecoveredPrivate(_x_) \
+	do { \
+		if (Q_UNLIKELY(d_ptr == Q_NULLPTR)) { \
+			CreditEventDeletedMessageRecoveredPrivate *p = new (::std::nothrow) CreditEventDeletedMessageRecoveredPrivate; \
+			if (Q_UNLIKELY(p == Q_NULLPTR)) { \
+				Q_ASSERT(0); \
+				return _x_; \
+			} \
+			d_ptr.reset(p); \
+		} \
+	} while (0)
+
+Isds::CreditEventDeletedMessageRecovered &Isds::CreditEventDeletedMessageRecovered::operator=(const CreditEventDeletedMessageRecovered &other) Q_DECL_NOTHROW
+{
+	if (other.d_func() == Q_NULLPTR) {
+		d_ptr.reset(Q_NULLPTR);
+		return *this;
+	}
+	ensureCreditEventDeletedMessageRecoveredPrivate(*this);
+	Q_D(CreditEventDeletedMessageRecovered);
+
+	*d = *other.d_func();
+
+	return *this;
+}
+
+#ifdef Q_COMPILER_RVALUE_REFS
+Isds::CreditEventDeletedMessageRecovered &Isds::CreditEventDeletedMessageRecovered::operator=(CreditEventDeletedMessageRecovered &&other) Q_DECL_NOTHROW
+{
+	swap(*this, other);
+	return *this;
+}
+#endif /* Q_COMPILER_RVALUE_REFS */
+
+bool Isds::CreditEventDeletedMessageRecovered::operator==(const CreditEventDeletedMessageRecovered &other) const
+{
+	Q_D(const CreditEventDeletedMessageRecovered);
+	if ((d == Q_NULLPTR) && ((other.d_func() == Q_NULLPTR))) {
+		return true;
+	} else if ((d == Q_NULLPTR) || ((other.d_func() == Q_NULLPTR))) {
+		return false;
+	}
+
+	return *d == *other.d_func();
+}
+
+bool Isds::CreditEventDeletedMessageRecovered::operator!=(const CreditEventDeletedMessageRecovered &other) const
+{
+	return !operator==(other);
+}
+
+bool Isds::CreditEventDeletedMessageRecovered::isNull(void) const
+{
+	Q_D(const CreditEventDeletedMessageRecovered);
+	return d == Q_NULLPTR;
+}
+
+const QString &Isds::CreditEventDeletedMessageRecovered::initiator(void) const
+{
+	Q_D(const CreditEventDeletedMessageRecovered);
+	if (Q_UNLIKELY(d == Q_NULLPTR)) {
+		return nullString;
+	}
+	return d->m_initiator;
+}
+
+void Isds::CreditEventDeletedMessageRecovered::setInitiator(const QString &i)
+{
+	ensureCreditEventDeletedMessageRecoveredPrivate();
+	Q_D(CreditEventDeletedMessageRecovered);
+	d->m_initiator = i;
+}
+
+#ifdef Q_COMPILER_RVALUE_REFS
+void Isds::CreditEventDeletedMessageRecovered::setInitiator(QString &&i)
+{
+	ensureCreditEventDeletedMessageRecoveredPrivate();
+	Q_D(CreditEventDeletedMessageRecovered);
+	d->m_initiator = ::std::move(i);
+}
+#endif /* Q_COMPILER_RVALUE_REFS */
+
+void Isds::swap(CreditEventDeletedMessageRecovered &first, CreditEventDeletedMessageRecovered &second) Q_DECL_NOTHROW
+{
+	using ::std::swap;
+	swap(first.d_ptr, second.d_ptr);
+}
+
 /*!
  * @brief PIMPL CreditEvent class.
  */
@@ -2872,7 +3023,7 @@ public:
 	CreditEventPrivate(void)
 	    : m_time(), m_creditChange(0), m_creditAfter(0),
 	    m_type(Type::CET_UNKNOWN), m_charged(), m_discharged(), m_msgSent(),
-	    m_storageSet()
+	    m_storageSet(), m_deletedMessageRecovered()
 	{ }
 
 	CreditEventPrivate &operator=(const CreditEventPrivate &other) Q_DECL_NOTHROW
@@ -2885,6 +3036,7 @@ public:
 		m_discharged = other.m_discharged;
 		m_msgSent = other.m_msgSent;
 		m_storageSet = other.m_storageSet;
+		m_deletedMessageRecovered = other.m_deletedMessageRecovered;
 
 		return *this;
 	}
@@ -2898,7 +3050,8 @@ public:
 		    (m_charged == other.m_charged) &&
 		    (m_discharged == other.m_discharged) &&
 		    (m_msgSent == other.m_msgSent) &&
-		    (m_storageSet == other.m_storageSet);
+		    (m_storageSet == other.m_storageSet) &&
+		    (m_deletedMessageRecovered == other.m_deletedMessageRecovered);
 	}
 
 	QDateTime m_time; /*!< Event time. */
@@ -2911,6 +3064,7 @@ public:
 	CreditEventDischarged m_discharged;
 	CreditEventMsgSent m_msgSent;
 	CreditEventStorageSet m_storageSet;
+	CreditEventDeletedMessageRecovered m_deletedMessageRecovered;
 };
 
 Isds::CreditEvent::CreditEvent(void)
@@ -3113,6 +3267,9 @@ void eraseEventContent(Isds::CreditEventPrivate *cep)
 	case Isds::Type::CET_EXPIRED:
 		/* Nothing to do. */
 		break;
+	case Isds::Type::CET_DELETED_MESSAGE_RECOVERED:
+		cep->m_deletedMessageRecovered = nullCreditEventDeletedMessageRecovered;
+		break;
 	default:
 		Q_ASSERT(0);
 		break;
@@ -3252,6 +3409,39 @@ void Isds::CreditEvent::setExpired(void)
 	d->m_type = Type::CET_EXPIRED;
 }
 
+const Isds::CreditEventDeletedMessageRecovered &Isds::CreditEvent::deletedMessageRecovered(void) const
+{
+	Q_D(const CreditEvent);
+	if (Q_UNLIKELY(d == Q_NULLPTR)) {
+		return nullCreditEventDeletedMessageRecovered;
+	}
+	return d->m_deletedMessageRecovered;
+}
+
+void Isds::CreditEvent::setDeletedMessageRecovered(const CreditEventDeletedMessageRecovered &cedmr)
+{
+	ensureCreditEventPrivate();
+	Q_D(CreditEvent);
+	if (d->m_type != Type::CET_DELETED_MESSAGE_RECOVERED) {
+		eraseEventContent(d);
+	}
+	d->m_deletedMessageRecovered = cedmr;
+	d->m_type = Type::CET_DELETED_MESSAGE_RECOVERED;
+}
+
+#ifdef Q_COMPILER_RVALUE_REFS
+void Isds::CreditEvent::setDeletedMessageRecovered(CreditEventDeletedMessageRecovered &&cedmr)
+{
+	ensureCreditEventPrivate();
+	Q_D(CreditEvent);
+	if (d->m_type != Type::CET_DELETED_MESSAGE_RECOVERED) {
+		eraseEventContent(d);
+	}
+	d->m_deletedMessageRecovered = ::std::move(cedmr);
+	d->m_type = Type::CET_DELETED_MESSAGE_RECOVERED;
+}
+#endif /* Q_COMPILER_RVALUE_REFS */
+
 void Isds::swap(CreditEvent &first, CreditEvent &second) Q_DECL_NOTHROW
 {
 	using ::std::swap;
