@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,6 +26,13 @@
 #include "src/datovka_shared/utility/date_time.h"
 
 const QString Utility::timeDisplayFormat("HH:mm:ss");
+
 const QString Utility::dateTimeDisplayFormat("dd.MM.yyyy HH:mm:ss");
+const QString Utility::dateTimeNoSecsDisplayFormat("dd.MM.yyyy HH:mm");
+
+const QString Utility::dataTimeMSecsHyphenFormat("dd.MM.yyyy-HH:mm:ss.zzz");
+
 const QString Utility::dateDisplayFormat("dd.MM.yyyy");
 const QString Utility::dateMonthNameDisplayFormat("dd. MMMM yyyy");
+
+const QString Utility::dateTimeFileSuffixFormat("yyyyMMdd-HHmmss-t");
