@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,11 +32,20 @@ namespace Utility {
 	 */
 	extern
 	const QString timeDisplayFormat;
+
 	extern
 	const QString dateTimeDisplayFormat;
+	extern
+	const QString dateTimeNoSecsDisplayFormat; /* No seconds, only minutes. */
+	extern
+	const QString dataTimeMSecsHyphenFormat; /* Milliseconds, hyphen between date and time, no space. */
+
 	extern
 	const QString dateDisplayFormat;
 	extern
 	const QString dateMonthNameDisplayFormat;
 
+	extern
+	const QString dateTimeFileSuffixFormat;
+
 }
