@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,6 +28,7 @@
 #include <QTimer>
 #include <QMenu>
 
+#include "src/datovka_shared/io/draft_db.h" /* DraftEntryList, DraftCounts are used in slots. Q_MOC_INCLUDE */
 #include "src/datovka_shared/json/basic.h" /* Json::Int64StringList is used in slots. Q_MOC_INCLUDE */
 #include "src/io/account_db.h"
 #include "src/io/message_db.h"
@@ -41,6 +42,7 @@
 #include "src/models/accounts_model.h"
 #include "src/models/attachments_model.h"
 #include "src/models/collapsible_account_proxy_model.h"
+#include "src/models/draft_model.h"
 #include "src/models/messages_model.h"
 #include "src/models/sort_filter_proxy_model.h"
 #include "src/settings/account.h"
@@ -213,8 +215,10 @@ private slots:
 
 	/*
 	 * @brief Back up stored data.
+	 *
+	 * @param[in] automaticNotification True if automatically invoked.
 	 */
-	void viewDataBackupDlg(void);
+	void viewDataBackupDlg(bool automaticNotification = false);
 
 	/*!
 	 * @brief Restore data from backup.
@@ -378,9 +382,9 @@ private slots:
 	void viewSignatureDetailsDlg(void);
 
 	/*!
-	 * @brief Verifies selected message and create response dialogue.
+	 * @brief Authenticate message dialogue.
 	 */
-	void viewVerifySelectedMessageDlg(void);
+	void viewAuthenticateMessageDlg(void);
 
 	/*!
 	 * @brief Open selected message in external application.
@@ -470,7 +474,7 @@ private slots:
 	/*!
 	 * @brief Authenticate message file dialogue.
 	 */
-	void viewAuthenticateMessageDlg(void);
+	void viewAuthenticateMessageFileDlg(void);
 
 	/*!
 	 * @brief View message from file dialogue.
@@ -693,7 +697,19 @@ private slots:
 	 */
 	void messageItemsSelectedMarkSettled(void);
 
+/* Draft context menu. */
+
+	/*!
+	 * @brief Delete selected drafts.
+	 */
+	void deleteSelectedDrafts(void);
+
 /* Filter-field-related actions. */
+	/*!
+	 * @brief Show message list or draft list filter.
+	 */
+	void showFilter(void);
+
 	/*!
 	 * @brief Show message list filter.
 	 */
@@ -704,6 +720,16 @@ private slots:
 	 */
 	void hideMessageFilter(void);
 
+	/*!
+	 * @brief Show draft list filter.
+	 */
+	void showDraftFilter(void);
+
+	/*!
+	 * @brief Hide draft list filter.
+	 */
+	void hideDraftFilter(void);
+
 /* Window state change. */
 	/*!
 	 * @brief Enable actions and other controls according to status.
@@ -728,6 +754,15 @@ private slots:
 	void updateMessageSelection(const QItemSelection &selected,
 	    const QItemSelection &deselected = QItemSelection());
 
+	/*!
+	 * @brief Updates daft selection.
+	 *
+	 * @param[in] selected Newly selected indexes.
+	 * @param[in] deselect Deselected indexes.
+	 */
+	void updateDraftSelection(const QItemSelection &selected,
+	    const QItemSelection &deselected = QItemSelection());
+
 	/*!
 	 * @brief Reload model and widget content according to account
 	 *     selection.
@@ -852,6 +887,14 @@ private slots:
 	 */
 	void viewAttachmentListContextMenu(const QPoint &point);
 
+	/*!
+	 * @brief Generates a context menu depending on the item and selection
+	 *     it was invoked on.
+	 *
+	 * @param[in] point Invocation position.
+	 */
+	void viewDraftListContextMenu(const QPoint &point);
+
 	/*!
 	 * @brief Used for toggling the message read state.
 	 *
@@ -864,6 +907,11 @@ private slots:
 	 */
 	void viewSelectedMessage(void);
 
+	/*!
+	 * @brief Handle draft double click.
+	 */
+	void openSelectedDraft(void);
+
 /* Handle settings changes. */
 	/*!
 	 * @brief Store INI settings.
@@ -963,6 +1011,34 @@ private slots:
 	 */
 	void watchIdentificationsDeleted(const Json::MsgId2List &msgIds);
 
+	/*!
+	 * @brief Update model when draft entries inserted.
+	 *
+	 * @param[in] entries Inserted entries.
+	 */
+	void watchDraftsInserted(const DraftEntryList &entries);
+
+	/*!
+	 * @brief Update model when draft entries modified.
+	 *
+	 * @param[in] entries Modified draft entries.
+	 */
+	void watchDraftsUpdated(const DraftEntryList &entries);
+
+	/*!
+	 * @brief Update model when draft entries deleted.
+	 *
+	 * @param[in] ids Deleted draft identifiers.
+	 */
+	void watchDraftsDeleted(const Json::Int64StringList &ids);
+
+	/*!
+	 * @brief Update model when draft entries deleted.
+	 *
+	 * @param[in] draftCounts Draft counts for accounts where it has changed.
+	 */
+	void watchDraftCountChanged(const DraftCounts &draftCounts);
+
 	/*!
 	 * @brief Update model data when records management entry is deleted.
 	 *
@@ -1125,6 +1201,11 @@ private slots:
 	 */
 	void filterMessages(const QString &text);
 
+	/*!
+	 * @brief Filter listed drafts.
+	 */
+	void filterDrafts(const QString &text);
+
 	/*!
 	 * @brief Set new sent/received message column widths.
 	 */
@@ -1273,7 +1354,7 @@ private:
 	 * @param[in] mwPtr Pointer to main window.
 	 */
 	static
-	void clearFilterLineViaFilter(QObject *mwPtr);
+	void clearMessageFilterLineViaFilter(QObject *mwPtr);
 
 	/*!
 	 * @brief Used to view message list filter line via event filter.
@@ -1281,7 +1362,7 @@ private:
 	 * @param[in] mwPtr Pointer to main window.
 	 */
 	static
-	void showFilterLineViaFilter(QObject *mwPtr);
+	void showMessageFilterLineViaFilter(QObject *mwPtr);
 
 	/*!
 	 * @brief Used to hide message list filter line via event filter.
@@ -1289,7 +1370,39 @@ private:
 	 * @param[in] mwPtr Pointer to main window.
 	 */
 	static
-	void hideFilterLineViaFilter(QObject *mwPtr);
+	void hideMessageFilterLineViaFilter(QObject *mwPtr);
+
+	/*!
+	 * @brief Used to open selected draft via event filter.
+	 *
+	 * @param[in] mwPtr Pointer to main window.
+	 */
+	static
+	void openSelectedDraftViaFilter(QObject *mwPtr);
+
+	/*!
+	 * @brief Used to clear draft list filter line via event filter.
+	 *
+	 * @param[in] mwPtr Pointer to main window.
+	 */
+	static
+	void clearDraftFilterLineViaFilter(QObject *mwPtr);
+
+	/*!
+	 * @brief Used to view draft list filter line via event filter.
+	 *
+	 * @param[in] mwPtr Pointer to main window.
+	 */
+	static
+	void showDraftFilterLineViaFilter(QObject *mwPtr);
+
+	/*!
+	 * @brief Used to hide draft list filter line via event filter.
+	 *
+	 * @param[in] mwPtr Pointer to main window.
+	 */
+	static
+	void hideDraftFilterLineViaFilter(QObject *mwPtr);
 
 	/*!
 	 * @brief Set info status bar from worker.
@@ -1357,9 +1470,11 @@ private:
 	 *
 	 * @param[in] action Defines send action (new,reply,forward,template).
 	 * @param[in] composeSerialised Serialised content data.
+	 * @param[in] draftEntry Draft entry.
 	 */
 	void showSendMessageDialog(int action,
-	    const QString &composeSerialised = QString());
+	    const QString &composeSerialised = QString(),
+	    const DraftEntry &draftEntry = DraftEntry());
 
 	/*!
 	 * @brief Set default account from settings.
@@ -1502,8 +1617,14 @@ private:
 	                                               * Used for message
 	                                               * sorting and filtering.
 	                                               */
+	AttachmentTblModel m_attachmentModel; /*!< Attachment table model. */
+	DraftTableModel m_draftModel; /*!< Draft table model. */
+	SortFilterProxyModel m_draftListProxyModel; /*!<
+	                                             * Used for message
+	                                             * sorting and filtering.
+	                                             */
+
 	QString m_dfltFilerLineStyleSheet; /*!< Used to remember default line edit style. */
-	AttachmentTblModel m_attachmentModel; /*! Attachment table model. */
 
 	QTimer m_messageMarker; /*!< Used for marking messages as read. */
 	qint64 m_lastSelectedMessageId; /*!< Id of the last selected message. */
