@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,15 +23,17 @@
 
 #include <QDir>
 #if (QT_VERSION < QT_VERSION_CHECK(5, 9, 0))
-#include <QDirIterator>
+#  include <QDirIterator>
 #endif /* < Qt-5.9 */
 #include <QFileDialog>
 #include <QMessageBox>
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 4, 0))
-#include <QStorageInfo>
+#  include <QStorageInfo>
 #else /* < Qt-5.4 */
-#warning "Compiling against version < Qt-5.4 which does not have QStorageInfo."
+#  warning "Compiling against version < Qt-5.4 which does not have QStorageInfo."
 #endif /* >= Qt-5.4 */
+#include <QStringBuilder>
+#include <QStringList>
 #include <QtGlobal> /* Q_INT64_C */
 
 #include "src/datovka_shared/identifiers/account_id.h"
@@ -70,23 +72,27 @@ static const QString accountTableName("account_list");
  * @brief Add data into the account model.
  *
  * @param[in,out] model Account model.
- * @param[in]     acntIdDbList Account list.
+ * @param[in] acntIdDbList Account list.
+ * @param[in] autoSelectedList List of selected data boxes.
  */
 static
 void initialiseAccountModel(BackupSelectionModel &model,
-    const QList<AcntIdDb> &acntIdDbList)
+    const QList<AcntIdDb> &acntIdDbList, const QStringList &autoSelectedList)
 {
 	foreach (const AcntIdDb &acntIdDb, acntIdDbList) {
 		const AcntId acntId(acntIdDb);
-		model.appendData(false, macroAccountName(acntId), acntId,
+		model.appendData(autoSelectedList.contains(acntId.strId()),
+		    macroAccountName(acntId), acntId,
 		    macroDataBoxId(acntIdDb.username()));
 	}
 }
 
-DlgBackup::DlgBackup(const QList<AcntIdDb> &acntIdDbList, QWidget *parent)
+DlgBackup::DlgBackup(const QList<AcntIdDb> &acntIdDbList, bool autoBackup,
+    QWidget *parent)
     : QDialog(parent),
     m_ui(new (::std::nothrow) Ui::DlgBackup),
     m_acntIdDbList(acntIdDbList),
+    m_autoBackup(autoBackup),
     m_backupVolume(),
     m_availableSpace(SPACE_UNKNOWN),
     m_requiredSpace(SPACE_UNKNOWN),
@@ -96,7 +102,14 @@ DlgBackup::DlgBackup(const QList<AcntIdDb> &acntIdDbList, QWidget *parent)
 
 	initDialogue();
 
-	initialiseAccountModel(m_backupSelectionModel, m_acntIdDbList);
+	QStringList autoSelectedList;
+
+	if (m_autoBackup) {
+		autoSelectedList = PrefsSpecific::autoBackupSelected(*GlobInstcs::prefsPtr);
+	}
+
+	initialiseAccountModel(m_backupSelectionModel, m_acntIdDbList,
+	    autoSelectedList);
 
 	computeRequiredSpace();
 	enableOkButton();
@@ -115,7 +128,8 @@ DlgBackup::~DlgBackup(void)
 	delete m_ui;
 }
 
-void DlgBackup::backup(const QList<AcntIdDb> &acntIdDbList, QWidget *parent)
+void DlgBackup::backup(const QList<AcntIdDb> &acntIdDbList, bool autoBackup,
+    QWidget *parent)
 {
 	if (Q_UNLIKELY(GlobInstcs::workPoolPtr->working())) {
 		logErrorNL("%s",
@@ -124,7 +138,7 @@ void DlgBackup::backup(const QList<AcntIdDb> &acntIdDbList, QWidget *parent)
 		return;
 	}
 
-	DlgBackup dlg(acntIdDbList, parent);
+	DlgBackup dlg(acntIdDbList, autoBackup, parent);
 
 	const QSize dfltSize = dlg.size();
 	{
@@ -361,9 +375,48 @@ bool isEmptyDir(const QDir &dir,
 #endif /* >= Qt-5.9 */
 }
 
+/*!
+ * @brief Create auto backup the directory path.
+ *
+ * @param[in] baseDir Base path.
+ * @return Path to existing directory, null string on any error.
+ */
+static
+QString autoBackupDir(const QString &baseDir)
+{
+	if (Q_UNLIKELY(baseDir.isEmpty())) {
+		Q_ASSERT(0);
+		return QString();
+	}
+
+	const QDateTime currentDateTime = QDateTime::currentDateTime();
+	QString subdir(QStringLiteral("Auto_Backup_")
+	    % currentDateTime.toString(Qt::ISODate).replace(":", "-"));
+	QDir dir(baseDir % QDir::separator() % subdir);
+	if (Q_UNLIKELY((!dir.exists()) && (!dir.mkpath(".")))) {
+		logErrorNL("Cannot create or access directory '%s'.",
+		    dir.absolutePath().toUtf8().constData());
+		return baseDir;
+	}
+
+	return dir.path();
+}
+
 void DlgBackup::backupSelected(void)
 {
-	const QString normDir(normalisedDir(m_ui->directoryLine->text(), this));
+	QString normDir;
+
+	if (m_autoBackup) {
+		const QString tgtDir = QDir::fromNativeSeparators(m_ui->directoryLine->text());
+
+		normDir = autoBackupDir(tgtDir);
+
+		/* Update path. */
+		PrefsSpecific::setAutoBackupPath(*GlobInstcs::prefsPtr, tgtDir);
+	} else {
+		normDir = normalisedDir(QDir::fromNativeSeparators(m_ui->directoryLine->text()), this);
+	}
+
 	if (Q_UNLIKELY(normDir.isEmpty())) {
 		logErrorNL("%s", "Cannot access directory to write a back-up into.");
 		return;
@@ -453,8 +506,12 @@ void DlgBackup::computeRequiredSpace(void)
 	 */
 	QApplication::setOverrideCursor(Qt::WaitCursor);
 
+	/* Contains account strIds. */
+	QStringList selected;
+
 	if (m_backupSelectionModel.numChecked() > 0) {
 		foreach (const AcntId &acntId, m_backupSelectionModel.checkedAcntIds()) {
+			selected.append(acntId.strId());
 			MessageDbSet *dbSet =
 			    GuiHelper::getDbSet(m_acntIdDbList, acntId);
 			if (Q_UNLIKELY(dbSet == Q_NULLPTR)) {
@@ -481,6 +538,11 @@ void DlgBackup::computeRequiredSpace(void)
 		}
 	}
 
+	/* Remember selected data boxes for automatic backup only. */
+	if (m_autoBackup) {
+		PrefsSpecific::setAutoBackupSelected(*GlobInstcs::prefsPtr, selected);
+	}
+
 	QApplication::restoreOverrideCursor();
 
 	if ((m_requiredSpace != SPACE_UNKNOWN) &&
@@ -525,13 +587,22 @@ void DlgBackup::showSizeNotificationIfNeeded(void)
 
 void DlgBackup::initDialogue(void)
 {
-	m_ui->infoLabel->setText(
-	    tr("Specify the location where you want to back up your data and select what data you want to back up. Selected data will be written into the specified location.") +
-	    QStringLiteral("\n") +
-	    tr("Don't modify any of the written files unless you really know what you are doing.") +
-	    QStringLiteral(" ") +
-	    tr("Preserve the back-up in a safe place as it contains private data."));
+	QString infoTxt;
 
+	if (m_autoBackup) {
+		infoTxt = tr("The predefined interval since last backup has elapsed.")
+		    + QStringLiteral("\n\n");
+		m_ui->directoryLine->setText(
+		    QDir::toNativeSeparators(PrefsSpecific::autoBackupPath(*GlobInstcs::prefsPtr)));
+	}
+
+	infoTxt += tr("Specify the location where you want to back up your data and select what data you want to back up. Selected data will be written into the specified location.")
+	    + QStringLiteral("\n")
+	    + tr("Don't modify any of the written files unless you really know what you are doing.")
+	    + QStringLiteral(" ")
+	    + tr("Preserve the back-up in a safe place as it contains private data.");
+
+	m_ui->infoLabel->setText(infoTxt);
 	m_ui->availableSpaceLabel->setText(QString());
 	m_ui->directoryLine->setReadOnly(true);
 
