@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1004,7 +1004,7 @@ QString DlgConvertExportForMobileApp::createZipArchive(const QString &zipDir,
 	const QDateTime currentDateTime = QDateTime::currentDateTime();
 	const QString dirName(QStringLiteral(APP_NAME) % QStringLiteral("-") %
 	    QStringLiteral("mobile") % QStringLiteral("_transfer_") %
-	    currentDateTime.toString(Qt::ISODate) %  QStringLiteral(".zip"));
+	    currentDateTime.toString(Qt::ISODate).replace(":", "-") %  QStringLiteral(".zip"));
 
 	/* Create ZIP file. */
 	QString zipFilePath = joinDirs(zipDir, dirName);
