@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -317,7 +317,7 @@ DlgConvertImportFromMobileApp::DlgConvertImportFromMobileApp(QWidget *parent)
 	/* Set table view model and properties. */
 	m_ui->accountTableView->setNarrowedLineHeight();
 	m_ui->accountTableView->horizontalHeader()->setDefaultAlignment(
-	    Qt::AlignLeft);
+	    Qt::AlignVCenter | Qt::AlignLeft);
 	m_ui->accountTableView->setSelectionMode(
 	    QAbstractItemView::ExtendedSelection);
 	m_ui->accountTableView->setSelectionBehavior(
