@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,7 +44,6 @@
 #include "src/io/account_db.h"
 #include "src/io/account_db_tables.h"
 #include "src/io/account_shadow_helper.h"
-#include "src/io/dbs.h"
 #include "src/io/isds_helper.h"
 #include "src/io/isds_sessions.h"
 #include "src/io/message_db_set_container.h"
@@ -377,8 +376,9 @@ QString DlgCreateAccount::htmlAccountInfo(const AcntData &acntData,
 	    GlobInstcs::accntDbPtr->getOwnerInfo2(acntDbKey)));
 	html.append(Html::Export::htmlDataboxUserInfoApp(
 	    GlobInstcs::accntDbPtr->getUserInfo2(acntDbKey)));
-	html.append(Html::Export::htmlPwdExpirDateInfoApp(qDateTimeToDbFormat(
-	    GlobInstcs::accntDbPtr->getPwdExpirFromDb(acntDbKey))));
+	html.append(Html::Export::htmlPwdExpirDateInfoApp(
+	    GlobInstcs::accntDbPtr->getPwdExpirFromDb(acntDbKey)
+	        .toString(Utility::dateTimeDisplayFormat)));
 	if (dbSet != Q_NULLPTR) {
 		html.append(Html::Export::htmlMsgDbLocationInfoApp(
 		    dbSet->fileNames()));
