@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
  */
 
 #include <QColorDialog>
+#include <QDir>
 #include <QFileDialog>
 #include <QMessageBox>
 #include <QString>
@@ -161,7 +162,7 @@ void DlgPreferences::setSavePath(void)
 	    QFileDialog::ShowDirsOnly | QFileDialog::DontResolveSymlinks);
 
 	if (!newDir.isEmpty()) {
-		m_ui->savePath->setText(newDir);
+		m_ui->savePath->setText(QDir::toNativeSeparators(newDir));
 	}
 }
 
@@ -171,7 +172,18 @@ void DlgPreferences::setAddFilePath(void)
 	    tr("Select Directory"), m_ui->addFilePath->text(),
 	    QFileDialog::ShowDirsOnly | QFileDialog::DontResolveSymlinks);
 	if (!newDir.isEmpty()) {
-		m_ui->addFilePath->setText(newDir);
+		m_ui->addFilePath->setText(QDir::toNativeSeparators(newDir));
+	}
+}
+
+void DlgPreferences::setSaveBackupPath(void)
+{
+	QString newDir = QFileDialog::getExistingDirectory(this,
+	    tr("Select Directory"), m_ui->backupPath->text(),
+	    QFileDialog::ShowDirsOnly | QFileDialog::DontResolveSymlinks);
+
+	if (!newDir.isEmpty()) {
+		m_ui->backupPath->setText(QDir::toNativeSeparators(newDir));
 	}
 }
 
@@ -438,8 +450,10 @@ void DlgPreferences::saveSettings(Prefs &prefs, PinSettings &pinSett) const
 	/* directories */
 	PrefsSpecific::setUseGlobalPaths(prefs,
 	    m_ui->enableGlobalPaths->isChecked());
-	PrefsSpecific::setSaveAttachDir(prefs, m_ui->savePath->text());
-	PrefsSpecific::setLoadAttachDir(prefs, m_ui->addFilePath->text());
+	PrefsSpecific::setSaveAttachDir(prefs,
+	    QDir::fromNativeSeparators(m_ui->savePath->text()));
+	PrefsSpecific::setLoadAttachDir(prefs,
+	    QDir::fromNativeSeparators(m_ui->addFilePath->text()));
 
 	/* saving */
 	prefs.setBoolVal(
@@ -467,6 +481,14 @@ void DlgPreferences::saveSettings(Prefs &prefs, PinSettings &pinSett) const
 	    "file_system.format.filename.every_attachment_acceptance_info",
 	    m_ui->allAttachDelInfoFileNameFmt->text());
 
+	/* backups */
+	PrefsSpecific::setAutoBackupEnabled(prefs,
+	    m_ui->enableBackupNotifications->isChecked());
+	PrefsSpecific::setAutoBackupPath(prefs,
+	    QDir::fromNativeSeparators(m_ui->backupPath->text()));
+	PrefsSpecific::setAutoBackupPeriodMonths(prefs,
+	    m_ui->backupMonthIntervalSpinBox->value());
+
 	/* language */
 	prefs.setStrVal("translation.language",
 	    indexToSettingsLang(m_ui->langComboBox->currentIndex()));
@@ -681,8 +703,10 @@ void DlgPreferences::initDialogue(const Prefs &prefs)
 	/* directories */
 	m_ui->enableGlobalPaths->setChecked(
 	    PrefsSpecific::useGlobalPaths(prefs));
-	m_ui->savePath->setText(PrefsSpecific::saveAttachDir(prefs));
-	m_ui->addFilePath->setText(PrefsSpecific::loadAttachDir(prefs));
+	m_ui->savePath->setText(
+	    QDir::toNativeSeparators(PrefsSpecific::saveAttachDir(prefs)));
+	m_ui->addFilePath->setText(
+	    QDir::toNativeSeparators(PrefsSpecific::loadAttachDir(prefs)));
 
 	connect(m_ui->savePathPushButton, SIGNAL(clicked()),
 	    this, SLOT(setSavePath()));
@@ -772,6 +796,16 @@ void DlgPreferences::initDialogue(const Prefs &prefs)
 		    this, SLOT(closeParamListDlg()));
 	}
 
+	/* backups */
+	m_ui->enableBackupNotifications->setChecked(
+	    PrefsSpecific::autoBackupEnabled(prefs));
+	m_ui->backupMonthIntervalSpinBox->setValue(
+	    PrefsSpecific::autoBackupPeriodMonths(prefs));
+	m_ui->backupPath->setText(
+	    QDir::toNativeSeparators(PrefsSpecific::autoBackupPath(prefs)));
+	connect(m_ui->backupPathPushButton, SIGNAL(clicked()),
+	    this, SLOT(setSaveBackupPath()));
+
 	/* language */
 	m_ui->langComboBox->addItem(tr("Use system language"));
 	m_ui->langComboBox->addItem(tr("Czech"));
