@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -129,6 +129,11 @@ private slots:
 	 */
 	void setAddFilePath(void);
 
+	/*!
+	 * @brief Sets path for backup saving.
+	 */
+	void setSaveBackupPath(void);
+
 	/*!
 	 * @brief Set PIN value.
 	 */
