@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
  * the two.
  */
 
+#include <QDir>
 #include <QFile>
 #include <QFileDialog>
 #include <QMap>
@@ -208,7 +209,7 @@ void DlgRestore::chooseJsonFile(void)
 		return;
 	}
 
-	m_ui->jsonLine->setText(jsonPath);
+	m_ui->jsonLine->setText(QDir::toNativeSeparators(jsonPath));
 
 	m_ui->backupTimeLabel->setText(backup.dateTime().isValid() ?
 	    tr("Backup was taken at %1.")
@@ -391,7 +392,7 @@ void DlgRestore::initDialogue(void)
 	m_ui->jsonLine->setReadOnly(true);
 
 	m_ui->accountView->setNarrowedLineHeight();
-	m_ui->accountView->horizontalHeader()->setDefaultAlignment(Qt::AlignLeft);
+	m_ui->accountView->horizontalHeader()->setDefaultAlignment(Qt::AlignVCenter | Qt::AlignLeft);
 	m_ui->accountView->setSelectionMode(QAbstractItemView::ExtendedSelection);
 	m_ui->accountView->setSelectionBehavior(QAbstractItemView::SelectRows);
 
@@ -474,7 +475,7 @@ qint64 backedMessageDbSize(const QString &backupDir,
 bool DlgRestore::checkAvailableSpace(void)
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 4, 0))
 {
-	const QString jsonPath(m_ui->jsonLine->text());
+	const QString jsonPath(QDir::fromNativeSeparators(m_ui->jsonLine->text()));
 	Json::Backup backup;
 	if (!readBackup(backup, jsonPath)) {
 		Q_ASSERT(0);
@@ -571,7 +572,7 @@ bool DlgRestore::checkAvailableSpace(void)
 void *DlgRestore::collectRestorationDescr(void) const
 {
 	Json::Backup backup;
-	const QString jsonPath(m_ui->jsonLine->text());
+	const QString jsonPath(QDir::fromNativeSeparators(m_ui->jsonLine->text()));
 
 	RestoreWorker::RestorationDescr *descr =
 	    new (::std::nothrow) RestoreWorker::RestorationDescr;
