@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
  */
 
 #include <algorithm> /* ::std::sort */
+#include <cinttypes> /* PRId64 */
 #include <QDateTime>
 #include <QDesktopServices>
 #include <QDir>
@@ -39,6 +40,7 @@
 #include "src/datovka_shared/isds/message_interface_vodz.h"
 #include "src/datovka_shared/isds/type_conversion.h"
 #include "src/datovka_shared/isds/types.h"
+#include "src/datovka_shared/json/draft_interface.h"
 #include "src/datovka_shared/localisation/localisation.h"
 #include "src/datovka_shared/log/log.h"
 #include "src/datovka_shared/settings/prefs.h"
@@ -61,7 +63,6 @@
 #include "src/identifiers/account_id_db.h"
 #include "src/identifiers/message_id.h"
 #include "src/io/account_db.h"
-#include "src/io/dbs.h"
 #include "src/io/exports.h"
 #include "src/io/filesystem.h"
 #include "src/io/isds_sessions.h"
@@ -90,15 +91,19 @@
 #define TAB_AUTHOR_INFO 2
 #define TAB_TEXT_MESSAGE 3
 
+#define DFLT_TEXT_FORMAT Utility::PLAIN_TEXT
+
 static const QString dlgName("send_message");
 static const QString recipTableName("recipient_list");
 static const QString attachmentTableName("attachment_list");
 
 DlgSendMessage::DlgSendMessage(const QList<AcntIdDb> &acntIdDbList,
     enum Action action, const QList<MsgId> &msgIds, const AcntId &acntId,
-    const QString &composeSerialised, class MainWindow *mw, QWidget *parent)
+    const QString &composeSerialised, const DraftEntry &draftEntry,
+    class MainWindow *mw, QWidget *parent)
     : QDialog(parent),
     m_ui(new (::std::nothrow) Ui::DlgSendMessage),
+    m_srcDraftEntry(draftEntry),
     m_acntIdDbList(acntIdDbList),
     m_acntId(acntId),
     m_boxId(),
@@ -164,6 +169,8 @@ DlgSendMessage::DlgSendMessage(const QList<AcntIdDb> &acntIdDbList,
 	initContent(action, msgIds);
 	if ((action == ACT_NEW) && !composeSerialised.isEmpty()) {
 		fillContentCompose(composeSerialised);
+	} else if (action == ACT_NEW_FROM_DRAFT) {
+		fillContentFromDraft(m_srcDraftEntry);
 	}
 
 	m_dfltSize = this->size();
@@ -221,6 +228,47 @@ void DlgSendMessage::showEvent(QShowEvent *event)
 	    dlgName, attachmentTableName));
 }
 
+void DlgSendMessage::done(int resultCode)
+{
+	/* Don't ask if global halt requested. */
+	if (!GlobInstcs::req_halt) {
+		/*
+		 * Don't ask when dialogue is accepted.
+		 * Dialogue is accepted only upon successful sending.
+		 */
+		if (resultCode != QDialog::Accepted) {
+			int ret = DlgMsgBoxDetail::message(this, QMessageBox::Question,
+			    tr("Save Message?"),
+			    tr("Save message as a draft and close the %1 dialogue?").arg(this->windowTitle()),
+			    QString(), QString(),
+			    QMessageBox::Save | QMessageBox::Discard | QMessageBox::Abort, QMessageBox::Save);
+			if (ret == QMessageBox::Abort) {
+				/* Don't close the dialogue. */
+				return;
+			}
+
+			if (ret == QMessageBox::Save) {
+				if (Q_UNLIKELY(!saveDraft())) {
+					/*
+					 * Don't close the dialogue if saving
+					 * fails.
+					 */
+					return;
+				}
+			}
+		} else {
+			/* Delete draft. */
+			if (m_srcDraftEntry.id >= 0) {
+				GlobInstcs::draftDbPtr->deleteDrafts(
+				    QList<qint64>() << m_srcDraftEntry.id);
+			}
+		}
+	}
+
+	/* Close the dialogue. */
+	QDialog::done(resultCode);
+}
+
 void DlgSendMessage::dmPublishOwnIdStateChanged(int state)
 {
 	m_ui->tabWidget->setTabEnabled(TAB_AUTHOR_INFO, state == Qt::Checked);
@@ -465,7 +513,7 @@ void DlgSendMessage::setAccountInfo(int fromComboIdx)
 	/* Get user name for selected account. */
 	AcntId acntId;
 	{
-		QVariant itemData = m_ui->fromComboBox->itemData(fromComboIdx);
+		const QVariant itemData = m_ui->fromComboBox->itemData(fromComboIdx);
 		if (Q_UNLIKELY(!itemData.canConvert<AcntId>())) {
 			Q_ASSERT(0);
 			return;
@@ -677,8 +725,20 @@ void DlgSendMessage::appendPdf(void)
 	m_ui->warningText->setText(QString());
 
 	if (!filePath.isEmpty()) {
+		/* Disconnect watchAppendedPdfModification() -> no warning text. */
+		m_attachModel.disconnect(SIGNAL(rowsRemoved(QModelIndex, int, int)),
+		    this, SLOT(watchAppendedPdfModification()));
+
+		/* There should be only one created from text. */
+		m_attachModel.removeAllCreatedFromText();
+
+		/* Reconnect watchAppendedPdfModification(). */
+		connect(&m_attachModel, SIGNAL(rowsRemoved(QModelIndex, int, int)),
+		    this, SLOT(watchAppendedPdfModification()));
+
+		/* Mark the new attachment as created from text. */
 		m_attachModel.insertAttachmentFile(filePath,
-		    m_attachModel.rowCount());
+		    m_attachModel.rowCount(), true);
 		m_ui->tabWidget->setCurrentIndex(TAB_BASIC);
 	}
 }
@@ -968,6 +1028,7 @@ void DlgSendMessage::initContent(enum Action action, const QList<MsgId> &msgIds)
 	m_ui->attachTableView->setColumnHidden(AttachmentTblModel::ATTACHID_COL, true);
 	m_ui->attachTableView->setColumnHidden(AttachmentTblModel::MSGID_COL, true);
 	m_ui->attachTableView->setColumnHidden(AttachmentTblModel::BINARY_CONTENT_COL, true);
+	m_ui->attachTableView->setColumnHidden(AttachmentTblModel::CREATED_FROM_TEXT_COL, true);
 
 	/* Enable drag and drop on attachment table. */
 	m_ui->attachTableView->setAcceptDrops(true);
@@ -1144,14 +1205,18 @@ void DlgSendMessage::initContent(enum Action action, const QList<MsgId> &msgIds)
 		m_ui->dmAllowSubstDelivery->hide();
 	}
 
-	if (ACT_REPLY == action) {
+	switch (action) {
+	case ACT_REPLY:
 		fillContentAsReply(msgIds);
-	} else {
-		if (ACT_NEW_FROM_TMP == action) {
-			fillContentFromTemplate(msgIds);
-		} else if (ACT_FORWARD == action) {
-			fillContentAsForward(msgIds);
-		}
+		break;
+	case ACT_FORWARD:
+		fillContentAsForward(msgIds);
+		break;
+	case ACT_NEW_FROM_TMPLT:
+		fillContentFromTemplate(msgIds);
+		break;
+	default:
+		break;
 	}
 
 	this->adjustSize();
@@ -1251,6 +1316,47 @@ void DlgSendMessage::fillContentAsReply(const QList<MsgId> &msgIds)
 	addRecipientBox(envData.dbIDSender(), canUseInitReply);
 }
 
+void DlgSendMessage::fillContentFromEnvelope(const Isds::Envelope &envel)
+{
+	m_ui->subjectLine->setText(envel.dmAnnotation());
+
+	/* Fill in optional fields.  */
+	if (!envel.dmSenderRefNumber().isEmpty()) {
+		m_ui->dmSenderRefNumber->setText(envel.dmSenderRefNumber());
+	}
+	if (!envel.dmSenderIdent().isEmpty()) {
+		m_ui->dmSenderIdent->setText(envel.dmSenderIdent());
+	}
+	if (!envel.dmRecipientRefNumber().isEmpty()) {
+		m_ui->dmRecipientRefNumber->setText(envel.dmRecipientRefNumber());
+	}
+	if (!envel.dmRecipientIdent().isEmpty()) {
+		m_ui->dmRecipientIdent->setText(envel.dmRecipientIdent());
+	}
+	if (!envel.dmToHands().isEmpty()) {
+		m_ui->dmToHands->setText(envel.dmToHands());
+	}
+	/* set check boxes */
+	m_ui->dmPersonalDelivery->setChecked(envel.dmPersonalDelivery());
+	m_ui->dmAllowSubstDelivery->setChecked(envel.dmAllowSubstDelivery());
+	/* fill optional LegalTitle - Law, year, ... */
+	if (!envel.dmLegalTitleLawStr().isEmpty()) {
+		m_ui->dmLegalTitleLaw->setText(envel.dmLegalTitleLawStr());
+	}
+	if (!envel.dmLegalTitleYearStr().isEmpty()) {
+		m_ui->dmLegalTitleYear->setText(envel.dmLegalTitleYearStr());
+	}
+	if (!envel.dmLegalTitleSect().isEmpty()) {
+		m_ui->dmLegalTitleSect->setText(envel.dmLegalTitleSect());
+	}
+	if (!envel.dmLegalTitlePar().isEmpty()) {
+		m_ui->dmLegalTitlePar->setText(envel.dmLegalTitlePar());
+	}
+	if (!envel.dmLegalTitlePoint().isEmpty()) {
+		m_ui->dmLegalTitlePoint->setText(envel.dmLegalTitlePoint());
+	}
+}
+
 void DlgSendMessage::fillContentFromTemplate(const QList<MsgId> &msgIds)
 {
 	debugFuncCall();
@@ -1274,43 +1380,7 @@ void DlgSendMessage::fillContentFromTemplate(const QList<MsgId> &msgIds)
 	m_dmType = Isds::char2DmType(envData.dmType());
 	m_dmSenderRefNumber = envData.dmRecipientRefNumber();
 
-	m_ui->subjectLine->setText(envData.dmAnnotation());
-
-	/* Fill in optional fields.  */
-	if (!envData.dmSenderRefNumber().isEmpty()) {
-		m_ui->dmSenderRefNumber->setText(envData.dmSenderRefNumber());
-	}
-	if (!envData.dmSenderIdent().isEmpty()) {
-		m_ui->dmSenderIdent->setText(envData.dmSenderIdent());
-	}
-	if (!envData.dmRecipientRefNumber().isEmpty()) {
-		m_ui->dmRecipientRefNumber->setText(envData.dmRecipientRefNumber());
-	}
-	if (!envData.dmRecipientIdent().isEmpty()) {
-		m_ui->dmRecipientIdent->setText(envData.dmRecipientIdent());
-	}
-	if (!envData.dmToHands().isEmpty()) {
-		m_ui->dmToHands->setText(envData.dmToHands());
-	}
-	/* set check boxes */
-	m_ui->dmPersonalDelivery->setChecked(envData.dmPersonalDelivery());
-	m_ui->dmAllowSubstDelivery->setChecked(envData.dmAllowSubstDelivery());
-	/* fill optional LegalTitle - Law, year, ... */
-	if (!envData.dmLegalTitleLawStr().isEmpty()) {
-		m_ui->dmLegalTitleLaw->setText(envData.dmLegalTitleLawStr());
-	}
-	if (!envData.dmLegalTitleYearStr().isEmpty()) {
-		m_ui->dmLegalTitleYear->setText(envData.dmLegalTitleYearStr());
-	}
-	if (!envData.dmLegalTitleSect().isEmpty()) {
-		m_ui->dmLegalTitleSect->setText(envData.dmLegalTitleSect());
-	}
-	if (!envData.dmLegalTitlePar().isEmpty()) {
-		m_ui->dmLegalTitlePar->setText(envData.dmLegalTitlePar());
-	}
-	if (!envData.dmLegalTitlePoint().isEmpty()) {
-		m_ui->dmLegalTitlePoint->setText(envData.dmLegalTitlePoint());
-	}
+	fillContentFromEnvelope(envData);
 
 	/* message is received -> recipient == sender */
 	if (m_boxId != envData.dbIDRecipient()) {
@@ -1340,11 +1410,11 @@ void selectAccount(QComboBox &fromComboBox, const QString &sender, QWidget *pare
 	int idx = 0;
 
 	for (; idx < fromComboBox.count(); ++idx) {
-		QVariant itemData = fromComboBox.itemData(idx);
+		const QVariant itemData = fromComboBox.itemData(idx);
 		if (Q_UNLIKELY(!itemData.canConvert<AcntId>())) {
 			continue;
 		}
-		AcntId acntId = qvariant_cast<AcntId>(itemData);
+		const AcntId acntId = qvariant_cast<AcntId>(itemData);
 
 		const QString acntDbKey(AccountDb::keyFromLogin(acntId.username()));
 		const Isds::DbOwnerInfoExt2 dbOwnerInfo =
@@ -1448,35 +1518,139 @@ void DlgSendMessage::fillContentCompose(const QString &composeSerialised)
 	}
 }
 
+/*!
+ * @brief Select text format from the combo box.
+ *
+ * @note Leaves selection if no match found.
+ *
+ * @param[in,out] fmtComboBox Combo box containing the text formats.
+ * @param[in] shortTextFmt Sought format.
+ */
+static
+void selectTextFormat(QComboBox &fmtComboBox, qint64 shortTextFmt)
+{
+	int idx = 0;
+
+	for (; idx < fmtComboBox.count(); ++idx) {
+		const QVariant itemData = fmtComboBox.itemData(idx);
+		if (Q_UNLIKELY(!itemData.canConvert<qint64>())) {
+			continue;
+		}
+		const qint64 fmtVal = itemData.toLongLong();
+
+		if (fmtVal == shortTextFmt) {
+			break;
+		}
+	}
+
+	/* Set select matching item. */
+	if (idx < fmtComboBox.count()) {
+		fmtComboBox.setCurrentIndex(idx);
+	} else {
+		logWarningNL(
+		    "No text format entry matching the value '%" PRId64 "' found.",
+		    UGLY_QINT64_CAST shortTextFmt);
+	}
+}
+
+void DlgSendMessage::fillContentFromDraft(const DraftEntry &draftEntry)
+{
+	debugFuncCall();
+
+	if (Q_UNLIKELY(draftEntry.id < 0)) {
+		logErrorNL("%s",
+		    "Ignoring draft entry with invalid identifier.");
+		return;
+	}
+
+	if (draftEntry.acntId.isValid()) {
+		selectAccount(*(m_ui->fromComboBox), draftEntry.acntId.username(), this);
+	}
+
+	fillContentFromEnvelope(draftEntry.dmDraft.dmEnvelope());
+
+	addRecipientBoxes(draftEntry.dmDraft.dmRecipients());
+
+	for (const Json::DmDraft::Attachment &attach : draftEntry.dmDraft.dmAttachments()) {
+		/* Only take paths. */
+		const QString &path = attach.path();
+		if (!path.isEmpty()) {
+			insertAttachmentFile(path, attach.createdFromText());
+		}
+	}
+
+	m_ui->textMessageEdit->setPlainText(draftEntry.dmDraft.shortMessageText());
+
+	{
+		const qint64 shortTextFmt = draftEntry.dmDraft.shortMessageTextFmt();
+		if ((shortTextFmt >= 0) && (shortTextFmt != DFLT_TEXT_FORMAT)) {
+			selectTextFormat(*(m_ui->textFormatComboBox), shortTextFmt);
+		}
+	}
+
+	if (m_ui->immDownloadCheckBox->isEnabled()) {
+		m_ui->immDownloadCheckBox->setChecked(draftEntry.dmDraft.cntrlDowmloadMessage());
+	}
+
+	if (m_ui->immRecMgmtUploadCheckBox->isEnabled()) {
+		m_ui->immRecMgmtUploadCheckBox->setChecked(draftEntry.dmDraft.cntrlUploadMessageRm());
+	}
+
+	if (draftEntry.dmDraft.dmEnvelope().dmPublishOwnID() == Isds::Type::BOOL_TRUE) {
+		/* Leave dialogue defaults if not set in draft. */
+		m_ui->dmPublishOwnId->setChecked(true);
+	}
+	{
+		int idLevel = draftEntry.dmDraft.dmEnvelope().idLevel();
+		if ((idLevel != Isds::Type::IDLEV_NULL) && (idLevel != 0)) {
+			/* Leave dialogue defaults if not set in draft. */
+			m_ui->dmPublishOwnId->setChecked(idLevel != 0);
+			m_ui->aiFullNameCheckBox->setChecked(idLevel & Isds::Type::IDLEV_PUBLISH_PERSONNAME);
+			m_ui->aiBirthDateCheckBox->setChecked(idLevel & Isds::Type::IDLEV_PUBLISH_BIDATE);
+			m_ui->aiBirthCityCheckBox->setChecked(idLevel & Isds::Type::IDLEV_PUBLISH_BICITY);
+			m_ui->aiBirthCountyCheckBox->setChecked(idLevel & Isds::Type::IDLEV_PUBLISH_BICOUNTY);
+			m_ui->aiRuianCodeCheckBox->setChecked(idLevel & Isds::Type::IDLEV_PUBLISH_ADCODE);
+			m_ui->aiFullAddressCheckBox->setChecked(idLevel & Isds::Type::IDLEV_PUBLISH_FULLADDRESS);
+			m_ui->aiRobIdentCheckBox->setChecked(idLevel & Isds::Type::IDLEV_PUBLISH_ROBIDENT);
+		}
+	}
+}
+
+void DlgSendMessage::insertAttachmentFile(const QString &filePath,
+    bool createdFromText)
+{
+	int fileSize = m_attachModel.insertAttachmentFile(filePath,
+	    m_attachModel.rowCount(), createdFromText);
+	switch (fileSize) {
+	case AttachmentTblModel::FILE_NOT_EXISTENT:
+		QMessageBox::warning(this, tr("Non-existent file"),
+		    tr("Cannot add non-existent file '%1' to attachments.").arg(filePath),
+		    QMessageBox::Ok, QMessageBox::Ok);
+		break;
+	case AttachmentTblModel::FILE_NOT_READABLE:
+		QMessageBox::warning(this, tr("File not readable"),
+		    tr("Cannot add file '%1' without readable permissions to attachments.").arg(filePath),
+		    QMessageBox::Ok, QMessageBox::Ok);
+		break;
+	case AttachmentTblModel::FILE_ALREADY_PRESENT:
+		QMessageBox::warning(this, tr("File already present"),
+		    tr("Cannot add file '%1' because the file is already present in the attachments.").arg(filePath),
+		    QMessageBox::Ok, QMessageBox::Ok);
+		break;
+	case AttachmentTblModel::FILE_ZERO_SIZE:
+		QMessageBox::warning(this, tr("Empty file"),
+		    tr("Cannot add empty file '%1' to attachments.").arg(filePath),
+		    QMessageBox::Ok, QMessageBox::Ok);
+		break;
+	default:
+		break;
+	}
+}
+
 void DlgSendMessage::insertAttachmentFiles(const QStringList &filePaths)
 {
 	for (const QString &filePath : filePaths) {
-		int fileSize = m_attachModel.insertAttachmentFile(filePath,
-		    m_attachModel.rowCount());
-		switch (fileSize) {
-		case AttachmentTblModel::FILE_NOT_EXISTENT:
-			QMessageBox::warning(this, tr("Non-existent file"),
-			    tr("Cannot add non-existent file '%1' to attachments.").arg(filePath),
-			    QMessageBox::Ok, QMessageBox::Ok);
-			break;
-		case AttachmentTblModel::FILE_NOT_READABLE:
-			QMessageBox::warning(this, tr("File not readable"),
-			    tr("Cannot add file '%1' without readable permissions to attachments.").arg(filePath),
-			    QMessageBox::Ok, QMessageBox::Ok);
-			break;
-		case AttachmentTblModel::FILE_ALREADY_PRESENT:
-			QMessageBox::warning(this, tr("File already present"),
-			    tr("Cannot add file '%1' because the file is already present in the attachments.").arg(filePath),
-			    QMessageBox::Ok, QMessageBox::Ok);
-			break;
-		case AttachmentTblModel::FILE_ZERO_SIZE:
-			QMessageBox::warning(this, tr("Empty file"),
-			    tr("Cannot add empty file '%1' to attachments.").arg(filePath),
-			    QMessageBox::Ok, QMessageBox::Ok);
-			break;
-		default:
-			break;
-		}
+		insertAttachmentFile(filePath);
 	}
 }
 
@@ -1977,6 +2151,122 @@ bool DlgSendMessage::buildDocuments(QList<Isds::Document> &documents) const
 	return true;
 }
 
+bool DlgSendMessage::buildDraft(Json::DmDraft &dmDraft) const
+{
+	{
+		Isds::Envelope envelope;
+		if (Q_UNLIKELY(!buildEnvelope(envelope))) {
+			return false;
+		}
+
+		dmDraft.setDmEnvelope(macroStdMove(envelope));
+	}
+
+	dmDraft.setDmRecipients(
+	    m_recipTableModel.boxIdentifiers(BoxContactsModel::ANY));
+
+	{
+		Json::DmDraft::AttachmentList attachments;
+
+		for (int row = 0; row < m_attachModel.rowCount(); ++row) {
+			Json::DmDraft::Attachment attachment;
+			QModelIndex index;
+
+			index = m_attachModel.index(row,
+			    AttachmentTblModel::FNAME_COL);
+			if (Q_UNLIKELY(!index.isValid())) {
+				Q_ASSERT(0);
+				continue;
+			}
+			attachment.setName(index.data().toString());
+
+			index = m_attachModel.index(row,
+			    AttachmentTblModel::FPATH_COL);
+			QString fPath =
+			   index.data(AttachmentTblModel::ROLE_PLAIN_DISPLAY).toString();
+			if (!fPath.isEmpty()) {
+				attachment.setPath(macroStdMove(fPath));
+			} else {
+				index = m_attachModel.index(row,
+				    AttachmentTblModel::BINARY_CONTENT_COL);
+				attachment.setData(
+				    index.data(Qt::DisplayRole).toByteArray());
+			}
+
+			index = m_attachModel.index(row,
+			    AttachmentTblModel::CREATED_FROM_TEXT_COL);
+			bool createdFromText =
+			    index.data(AttachmentTblModel::ROLE_PLAIN_DISPLAY).toBool();
+			if (createdFromText) {
+				attachment.setCreatedFromText(createdFromText);
+			}
+
+			attachments.append(attachment);
+		}
+
+		dmDraft.setDmAttachments(macroStdMove(attachments));
+	}
+
+	dmDraft.setShortMessageText(m_ui->textMessageEdit->toPlainText());
+
+	{
+		const qint64 shortTextFmt = m_ui->textFormatComboBox->currentData().toLongLong();
+		if (shortTextFmt != DFLT_TEXT_FORMAT) {
+			dmDraft.setShortMessageTextFmt(shortTextFmt);
+		}
+	}
+
+	if (m_ui->immDownloadCheckBox->isEnabled()) {
+		dmDraft.setCntrlDowmloadMessage(m_ui->immDownloadCheckBox->checkState() == Qt::Checked);
+	}
+
+	if (m_ui->immRecMgmtUploadCheckBox->isEnabled()) {
+		dmDraft.setCntrlUploadMessageRm(m_ui->immRecMgmtUploadCheckBox->checkState() == Qt::Checked);
+	}
+
+	return true;
+}
+
+bool DlgSendMessage::saveDraft(void)
+{
+	Json::DmDraft dmDraft;
+
+	if (Q_UNLIKELY(!buildDraft(dmDraft))) {
+		logErrorNL("Cannot collect draft data for account '%s'.",
+		    m_acntId.username().toUtf8().constData());
+		QMessageBox::warning(this, DlgSendMessage::tr("Cannot Build Draft"),
+		    tr("Cannot create draft for data box '%1'.").arg(
+		    GlobInstcs::acntMapPtr->acntData(m_acntId).accountName() +
+		    " (" + m_acntId.username() + ")"),
+		    QMessageBox::Ok, QMessageBox::Ok);
+		return false;
+	}
+
+	if (m_srcDraftEntry.id < 0) {
+		if (Q_UNLIKELY(!GlobInstcs::draftDbPtr->insertDraft(
+		        m_acntId, dmDraft))) {
+			QMessageBox::warning(this, DlgSendMessage::tr("Cannot Save Draft"),
+			    tr("Cannot save draft for data box '%1'.").arg(
+			    GlobInstcs::acntMapPtr->acntData(m_acntId).accountName() +
+			    " (" + m_acntId.username() + ")"),
+			    QMessageBox::Ok, QMessageBox::Ok);
+			return false;
+		}
+	} else {
+		if (Q_UNLIKELY(!GlobInstcs::draftDbPtr->updateDraft(
+		        m_srcDraftEntry.id, m_acntId, dmDraft))) {
+			QMessageBox::warning(this, DlgSendMessage::tr("Cannot Update Draft"),
+			    tr("Cannot update draft for data box '%1'.").arg(
+			    GlobInstcs::acntMapPtr->acntData(m_acntId).accountName() +
+			    " (" + m_acntId.username() + ")"),
+			    QMessageBox::Ok, QMessageBox::Ok);
+			return false;
+		}
+	}
+
+	return true;
+}
+
 bool DlgSendMessage::startUploadAttachments(void)
 {
 	const QString timeStr = QDateTime::currentDateTimeUtc().toString();
