@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,9 +25,9 @@
 #include <QSslCertificate>
 #include <QTimeZone>
 
-#include "src/crypto/crypto.h"
-#include "src/crypto/crypto_funcs.h"
-#include "src/crypto/crypto_wrapped.h"
+#include "src/datovka_shared/crypto/crypto.h"
+#include "src/datovka_shared/crypto/crypto_funcs.h"
+#include "src/datovka_shared/crypto/crypto_wrapped.h"
 #include "src/datovka_shared/isds/types.h"
 #include "src/datovka_shared/log/log.h"
 #include "src/datovka_shared/utility/date_time.h"
