@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 #include <QPropertyAnimation>
 #include <QSet>
 
+#include "src/datovka_shared/io/filesystem.h"
 #include "src/datovka_shared/log/log.h"
 #include "src/datovka_shared/settings/prefs.h"
 #include "src/datovka_shared/utility/strings.h" /* Utility::generateRandomString */
@@ -40,7 +41,6 @@
 #include "src/gui/dlg_view_zfo.h"
 #include "src/gui/message_operations.h" /* MsgOrigin */
 #include "src/global.h"
-#include "src/io/filesystem.h"
 #include "src/io/isds_sessions.h"
 #include "src/io/message_db_set_container.h"
 #include "src/io/message_db_set.h"
@@ -347,6 +347,29 @@ void DlgTimestampRenewal::done(int resultCode)
 		m_externalTask->requestQuit();
 	}
 
+	/*
+	 * Wait for tasks to finish and collect them if to global shutdown
+	 * required.
+	 *
+	 * TODO -- A better way to dispose discarded tasks must be implemented.
+	 *
+	 * The use of QCoreApplication::processEvents() is discouraged by Qt
+	 * documentation.
+	 *
+	 * Extend worker/pool interface to accommodate more generic approach.
+	 * All tasks should have a transaction/stak identifier.
+	 * All tasks should have a requestQuit() method.
+	 * The pool could have a storage for finished tasks.
+	 * Finished tasks should be acquired via a poll interface rather than
+	 * remembering their pointers in the caller code.
+	 * Uncollected tasks should be deleted after a period of time?
+	 */
+	if (!GlobInstcs::req_halt) {
+		while ((!m_tasks.empty()) || (Q_NULLPTR != m_externalTask)) {
+			QCoreApplication::processEvents(QEventLoop::AllEvents, 100);
+		}
+	}
+
 	/* Close the dialogue. */
 	QDialog::done(resultCode);
 }
@@ -551,6 +574,8 @@ void DlgTimestampRenewal::filterMessages(const QString &text)
 	}
 }
 
+#define ANIMATION_DURATION 250
+
 void DlgTimestampRenewal::showMessageFilter(void)
 {
 	if (!m_ui->messagesFilterHorizontalLayout->isVisible()) {
@@ -561,7 +586,7 @@ void DlgTimestampRenewal::showMessageFilter(void)
 		    new (::std::nothrow) QPropertyAnimation(
 		        m_ui->messagesFilterHorizontalLayout, "maximumHeight");
 		if (Q_NULLPTR != animation) {
-			animation->setDuration(250);
+			animation->setDuration(ANIMATION_DURATION);
 			animation->setStartValue(0);
 			animation->setEndValue(
 			    m_ui->messagesFilterHorizontalLayout->sizeHint().height());
@@ -580,7 +605,7 @@ void DlgTimestampRenewal::hideMessageFilter(void)
 		    new (::std::nothrow) QPropertyAnimation(
 		        m_ui->messagesFilterHorizontalLayout, "maximumHeight");
 		if (Q_NULLPTR != animation) {
-			animation->setDuration(250);
+			animation->setDuration(ANIMATION_DURATION);
 			animation->setStartValue(
 			    m_ui->messagesFilterHorizontalLayout->height());
 			animation->setEndValue(0);
@@ -597,6 +622,8 @@ void DlgTimestampRenewal::hideMessageFilter(void)
 	m_ui->trackedMessagesView->setFocus(Qt::OtherFocusReason);
 }
 
+#undef ANIMATION_DURATION
+
 void DlgTimestampRenewal::watchIdentificationsInserted(
     const Json::MsgId2List &msgIds, const AcntId &acntId)
 {
@@ -1178,12 +1205,8 @@ void DlgTimestampRenewal::databaseConnectActions(void)
 		connect(m_timestampDb, SIGNAL(identificationsDeleted(Json::MsgId2List)),
 		    this, SLOT(watchIdentificationsDeleted(Json::MsgId2List)));
 		connect(m_timestampDb, SIGNAL(msgTimestampDataUpdated(TstValidityHash)),
-		    this, SLOT(watchMsgTimestampDataUpdated(TstValidityHash)));
-		/*
-		 * When using Qt::QueuedConnection for
-		 * msgTimestampDataUpdated() then the slot doesn't get called.
-		 * TODO -- Find the cause.
-		 */
+		    this, SLOT(watchMsgTimestampDataUpdated(TstValidityHash)),
+		    Qt::QueuedConnection); /* Qt::QueuedConnection because it must be executed in receiver's thread. */
 	}
 }
 
