@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,8 +26,8 @@
 #include <QMenu>
 #include <QTimeZone>
 
-#include "src/crypto/crypto_funcs.h"
-#include "src/crypto/crypto_wrapped.h"
+#include "src/datovka_shared/crypto/crypto_funcs.h"
+#include "src/datovka_shared/crypto/crypto_wrapped.h"
 #include "src/datovka_shared/html/html_export.h"
 #include "src/datovka_shared/isds/type_conversion.h"
 #include "src/datovka_shared/isds/type_description.h"
@@ -40,7 +40,6 @@
 #include "src/gui/dlg_signature_detail.h"
 #include "src/gui/dlg_view_zfo.h"
 #include "src/gui/icon_container.h"
-#include "src/io/dbs.h"
 #include "src/io/filesystem.h"
 #include "src/model_interaction/attachment_interaction.h"
 #include "src/model_interaction/view_interaction.h"
@@ -134,22 +133,6 @@ void DlgViewZfo::view(const QString &zfoFileName, QWidget *parent)
 	    dlg.size(), dfltSize);
 }
 
-void DlgViewZfo::showEvent(QShowEvent *event)
-{
-	QDialog::showEvent(event);
-
-	Dimensions::setRelativeTableColumnWidths(m_ui->attachmentTable,
-	    PrefsSpecific::dlgTblRelColWidths(*GlobInstcs::prefsPtr,
-	    dlgName, attachmentTableName));
-	Dimensions::setTableColumnSortOrder(m_ui->attachmentTable,
-	    PrefsSpecific::dlgTblColSortOrder(*GlobInstcs::prefsPtr,
-	    dlgName, attachmentTableName));
-
-	Dimensions::setSplitterSize(m_ui->splitter,
-	    PrefsSpecific::dlgSplitterSize(*GlobInstcs::prefsPtr,
-	    dlgName, dlgSplitterName));
-}
-
 void DlgViewZfo::view(const QByteArray &zfoData, QWidget *parent)
 {
 	enum Isds::LoadType zfoType = Isds::LT_ANY;
@@ -176,6 +159,22 @@ void DlgViewZfo::view(const QByteArray &zfoData, QWidget *parent)
 	    dlg.size(), dfltSize);
 }
 
+void DlgViewZfo::showEvent(QShowEvent *event)
+{
+	QDialog::showEvent(event);
+
+	Dimensions::setRelativeTableColumnWidths(m_ui->attachmentTable,
+	    PrefsSpecific::dlgTblRelColWidths(*GlobInstcs::prefsPtr,
+	    dlgName, attachmentTableName));
+	Dimensions::setTableColumnSortOrder(m_ui->attachmentTable,
+	    PrefsSpecific::dlgTblColSortOrder(*GlobInstcs::prefsPtr,
+	    dlgName, attachmentTableName));
+
+	Dimensions::setSplitterSize(m_ui->splitter,
+	    PrefsSpecific::dlgSplitterSize(*GlobInstcs::prefsPtr,
+	    dlgName, dlgSplitterName));
+}
+
 void DlgViewZfo::attachmentItemRightClicked(const QPoint &point)
 {
 	QModelIndex index(m_ui->attachmentTable->indexAt(point));
@@ -281,6 +280,8 @@ void DlgViewZfo::setUpDialogue(void)
 		    AttachmentTblModel::MIME_COL, true);
 		m_ui->attachmentTable->setColumnHidden(
 		    AttachmentTblModel::FPATH_COL, true);
+		m_ui->attachmentTable->setColumnHidden(
+		    AttachmentTblModel::CREATED_FROM_TEXT_COL, true);
 		m_ui->attachmentTable->resizeColumnToContents(
 		    AttachmentTblModel::FNAME_COL);
 
@@ -379,8 +380,20 @@ QString DlgViewZfo::htmlSignatureInfo(const QByteArray &msgDER,
 	}
 
 	QDateTime tstTime;
-	const bool valid = TstEntries::latestTstValid(msgDER, tstTime);
-	tsResStr = valid ? tr("Valid") : tr("Invalid");
+	const enum TstEntries::Validity valid = TstEntries::latestTstValid(msgDER, tstTime);
+	switch (valid) {
+	case TstEntries::MISSING:
+		tsResStr = tr("Missing");
+		break;
+	case TstEntries::VALID:
+		tsResStr = tr("Valid");
+		break;
+	case TstEntries::INVALID:
+		tsResStr = tr("Invalid");
+		break;
+	default:
+		break;
+	}
 	if (tstTime.isValid()) {
 		tsResStr += " (" + tstTime.toString(Utility::dateTimeDisplayFormat) + " " +
 		    tstTime.timeZone().abbreviation(tstTime) + ")";
