@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,9 +27,11 @@
 #include <QMimeType>
 #include <QProcess>
 
+#include "src/datovka_shared/io/filesystem.h"
 #include "src/datovka_shared/log/log.h"
 #include "src/datovka_shared/utility/strings.h" /* generateRandomString */
 #include "src/datovka_shared/settings/prefs.h"
+#include "src/datovka_shared/utility/date_time.h"
 #include "src/global.h"
 #include "src/gui/message_operations.h"
 #include "src/io/account_db.h"
@@ -226,7 +228,7 @@ static
 QString emailBoundary(void)
 {
 	return "-----" + Utility::generateRandomString(16) + "_" +
-	    QDateTime::currentDateTimeUtc().toString("dd.MM.yyyy-HH:mm:ss.zzz");
+	    QDateTime::currentDateTimeUtc().toString(Utility::dataTimeMSecsHyphenFormat);
 }
 
 /*!
