@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,12 +35,16 @@
 #include <QTranslator>
 
 #include "src/cli/cli_parser.h"
-#include "src/crypto/crypto_funcs.h"
 #include "src/datovka_shared/compat/compiler.h" /* macroStdMove */
+#include "src/datovka_shared/crypto/crypto_funcs.h"
 #include "src/datovka_shared/crypto/crypto_trusted_certs.h"
 #include "src/datovka_shared/identifiers/account_id.h"
 #include "src/datovka_shared/io/prefs_db.h"
 #include "src/datovka_shared/io/records_management_db.h"
+#include "src/datovka_shared/json/db_info.h"
+#if defined(ENABLE_DRAFTS)
+#  include "src/datovka_shared/io/draft_db.h"
+#endif /* defined(ENABLE_DRAFTS) */
 #include "src/datovka_shared/localisation/localisation.h"
 #include "src/datovka_shared/log/log.h"
 #include "src/datovka_shared/settings/pin.h"
@@ -65,7 +69,6 @@
 #  include "src/io/timestamp_db.h"
 #endif /* defined(ENABLE_TIMESTAMP_TRACKING) */
 #include "src/isds/qt_signal_slot.h"
-#include "src/json/db_info.h"
 #include "src/settings/accounts.h"
 #include "src/settings/preferences.h"
 #include "src/settings/prefs_specific.h"
@@ -410,6 +413,9 @@ void declareTypes(void)
 	Isds::declareTypes();
 	MessageDb::declareTypes();
 	MsgId::declareTypes();
+#if defined(ENABLE_TIMESTAMP_TRACKING)
+	TstValidityHash::declareTypes();
+#endif /* defined(ENABLE_TIMESTAMP_TRACKING) */
 }
 
 int allocGlobLog(void)
@@ -745,6 +751,24 @@ enum InitialisationError allocGlobContainers(const Prefs &prefs,
 		goto fail;
 	}
 
+#if defined(ENABLE_DRAFTS)
+	GlobInstcs::draftDbPtr = new (::std::nothrow) DraftDb("draftDb", false);
+	if (Q_UNLIKELY(GlobInstcs::draftDbPtr == Q_NULLPTR)) {
+		logErrorNL("%s", "Cannot allocate draft db.");
+		retCode = ERR_ALLOC_RESOURCES;
+		goto fail;
+	}
+	/* Open draft database. */
+	flags = SQLiteDb::CREATE_MISSING;
+	if (Q_UNLIKELY(!GlobInstcs::draftDbPtr->openDb(iniPrefs.draftDbPath(), flags))) {
+		logErrorNL("Error opening draft db '%s'.",
+		    iniPrefs.draftDbPath().toUtf8().constData());
+		problemPath = iniPrefs.draftDbPath();
+		retCode = ERR_OPEN_FILES;
+		goto fail;
+	}
+#endif /* defined(ENABLE_DRAFTS) */
+
 	GlobInstcs::acntMapPtr = new (::std::nothrow) AccountsMap(
 	    AcntContainer::CT_REGULAR);
 	if (Q_UNLIKELY(Q_NULLPTR == GlobInstcs::acntMapPtr)) {
@@ -783,6 +807,13 @@ void deallocGlobContainers(void)
 		GlobInstcs::acntMapPtr = Q_NULLPTR;
 	}
 
+#if defined(ENABLE_DRAFTS)
+	if (Q_NULLPTR != GlobInstcs::draftDbPtr) {
+		delete GlobInstcs::draftDbPtr;
+		GlobInstcs::draftDbPtr = Q_NULLPTR;
+	}
+#endif /* defined(ENABLE_DRAFTS) */
+
 	if (Q_NULLPTR != GlobInstcs::recMgmtDbPtr) {
 		delete GlobInstcs::recMgmtDbPtr;
 		GlobInstcs::recMgmtDbPtr = Q_NULLPTR;
