@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,11 +29,11 @@
 
 #include "src/datovka_shared/compat/compiler.h" /* macroStdMove */
 #include "src/datovka_shared/compat_qt/variant.h" /* nullVariantWhenIsNull */
+#include "src/datovka_shared/io/db_time.h"
 #include "src/datovka_shared/isds/type_conversion.h"
 #include "src/datovka_shared/log/log.h"
 #include "src/io/account_db.h"
 #include "src/io/account_db_tables.h"
-#include "src/io/dbs.h"
 
 DbEntry::DbEntry(void)
     : QMap<QString, QVariant>()
