@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,11 +22,11 @@
  */
 
 #include "src/datovka_shared/io/db_tables.h"
+#include "src/datovka_shared/io/message_db_tables.h"
 #include "src/datovka_shared/io/prefs_db_tables.h"
 #include "src/datovka_shared/io/records_management_db_tables.h"
 #include "src/datovka_shared/io/sqlite/table.h"
 #include "src/io/account_db_tables.h"
-#include "src/io/message_db_tables.h"
 #if defined(ENABLE_TAGS)
 #  include "src/io/tag_db_tables.h"
 #endif /* defined(ENABLE_TAGS) */
