@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,24 +21,19 @@
  * the two.
  */
 
-#include <QByteArray>
 #include <QCoreApplication>
-#include <QDateTime>
 #include <QDir>
-#include <QDirIterator>
 #include <QFile>
 #include <QFileInfo>
 #include <QLibraryInfo>
 #include <QRegularExpression>
 #include <QStandardPaths>
-#include <QStringBuilder>
 #include <QTemporaryDir>
 #include <QTemporaryFile>
 #include <QTextStream>
 
 #include "src/datovka_shared/log/log.h"
 #include "src/datovka_shared/settings/prefs.h"
-#include "src/datovka_shared/utility/date_time.h"
 #include "src/global.h"
 #include "src/io/filesystem.h"
 
@@ -84,20 +79,6 @@ void replaceBackslashes(QString &str)
 #undef ESCAPED_ILL_FNAME_CH
 #undef ILL_FNAME_REP
 
-bool createDirRecursive(const QString &dirPath)
-{
-	if (Q_UNLIKELY(dirPath.isEmpty())) {
-		return false;
-	}
-
-	QDir dir(dirPath);
-	if (dir.exists()) {
-		return true;
-	}
-
-	return dir.mkpath(".");
-}
-
 bool createDirStructureRecursive(const QString &filePath)
 {
 	if (Q_UNLIKELY(filePath.isEmpty())) {
@@ -112,165 +93,6 @@ bool createDirStructureRecursive(const QString &filePath)
 	return fileDir.mkpath(".");
 }
 
-bool copyDirRecursively(const QString &fromDirPath, const QString &toPath,
-    bool deleteOnError)
-{
-	if (Q_UNLIKELY(fromDirPath.isEmpty() || toPath.isEmpty())) {
-		return false;
-	}
-
-	{
-		const QFileInfo fromInfo(fromDirPath);
-		if (Q_UNLIKELY(((!fromInfo.isDir()) || (!fromInfo.isReadable())))) {
-			/* Not a readable directory. */
-			return false;
-		}
-
-		const QFileInfo toInfo(toPath);
-		if (Q_UNLIKELY((!toInfo.isDir()) || (!toInfo.isWritable()))) {
-			/* Not a writeable directory. */
-			return false;
-		}
-
-		const QString canonicalFrom = fromInfo.canonicalPath();
-		const QString canonicalTo = toInfo.canonicalPath();
-		if (Q_UNLIKELY(canonicalFrom.isEmpty() || canonicalTo.isEmpty())) {
-			Q_ASSERT(0);
-			return false;
-		}
-
-		if (Q_UNLIKELY(toPath.startsWith(fromDirPath))) {
-			/* Cannot copy from into its own subdirectory. */
-			return false;
-		}
-	}
-
-	const QString fromDirName = QFileInfo(fromDirPath).fileName();
-
-	QStringList toBecreatedDirs;
-	{
-		/* Search for subdirectories to be created. */
-		QDirIterator dirIt(fromDirPath, QStringList(),
-		    QDir::AllDirs | QDir::NoDotAndDotDot,
-		    QDirIterator::Subdirectories);
-		while (dirIt.hasNext()) {
-			dirIt.next();
-
-			const QString srcDirRelative =
-			    QDir(fromDirPath).relativeFilePath(dirIt.filePath());
-			const QString tgtDir = toPath + QStringLiteral("/") +
-			    fromDirName + QStringLiteral("/") + srcDirRelative;
-			{
-				const QFileInfo info(tgtDir);
-				if (info.exists() && ((!info.isDir()) || (!info.isWritable()))) {
-					logErrorNL("The path '%s' is not a writeable directory.",
-					    tgtDir.toUtf8().constData());
-					return false;
-				} else if (!info.exists()) {
-					toBecreatedDirs.append(tgtDir);
-				}
-			}
-		}
-	}
-
-	/* Create missing subdirectories. */
-	for (const QString &toPath : toBecreatedDirs) {
-		if (Q_UNLIKELY(!createDirRecursive(toPath))) {
-			logErrorNL("Cannot create directory '%s'.",
-			    toPath.toUtf8().constData());
-			goto fail;
-		}
-	}
-
-	{
-		/* Copy all files. */
-		QDirIterator dirIt(fromDirPath, QStringList(),
-		    QDir::Files | QDir::NoDotAndDotDot,
-		    QDirIterator::Subdirectories);
-		while (dirIt.hasNext()) {
-			dirIt.next();
-
-			const QString srcFileRelative =
-			    QDir(fromDirPath).relativeFilePath(dirIt.filePath());
-			const QString tgtFile = toPath + QStringLiteral("/") +
-			    fromDirName + QStringLiteral("/") + srcFileRelative;
-
-			QFile::remove(tgtFile); /* Just remove target if already exists. */
-			if (Q_UNLIKELY(!QFile::copy(dirIt.filePath(), tgtFile))) {
-				logErrorNL("Cannot copy file '%s' to '%s'.",
-				    dirIt.filePath().toUtf8().constData(),
-				    tgtFile.toUtf8().constData());
-				goto fail;
-			}
-		}
-	}
-
-	return true;
-
-fail:
-	if (deleteOnError) {
-		for (const QString &toPath : toBecreatedDirs) {
-			QDir(toPath).removeRecursively();
-		}
-		/* It doesn't delete newly copied files. */
-	}
-	return false;
-}
-
-QString nonconflictingFileName(QString filePath)
-{
-	if (Q_UNLIKELY(filePath.isEmpty())) {
-		return QString();
-	}
-
-	if (QFile::exists(filePath)) {
-
-		int fileCnt = 0;
-		QFileInfo fi(filePath);
-
-		const QString baseName(fi.baseName());
-		const QString path(fi.path());
-		const QString suffix(fi.completeSuffix());
-
-		do {
-			++fileCnt;
-			QString newName(
-			    baseName + "_" + QString::number(fileCnt));
-			filePath =
-			    path + QDir::separator() + newName + "." + suffix;
-		} while (QFile::exists(filePath));
-	}
-
-	return filePath;
-}
-
-enum WriteFileState writeFile(const QString &filePath, const QByteArray &data,
-    bool deleteOnError)
-{
-	if (Q_UNLIKELY(filePath.isEmpty())) {
-		Q_ASSERT(0);
-		return WF_ERROR;
-	}
-
-	QFile fout(filePath);
-	if (Q_UNLIKELY(!fout.open(QIODevice::WriteOnly))) {
-		return WF_CANNOT_CREATE;
-	}
-
-	qint64 written = fout.write(data);
-	bool flushed = fout.flush();
-	fout.close();
-
-	if (Q_UNLIKELY((written != data.size()) || !flushed)) {
-		if (deleteOnError) {
-			QFile::remove(filePath);
-		}
-		return WF_CANNOT_WRITE_WHOLE;
-	}
-
-	return WF_SUCCESS;
-}
-
 /*!
  * @brief Try to determine whether parent holds child.
  *
@@ -520,13 +342,6 @@ QString confDirPath(const QString &confBaseDir, const QString &confSubdir)
 	}
 }
 
-QString auxConfFilePath(const QString &filePath)
-{
-	return filePath % QStringLiteral(".aux.")
-	    % QDateTime::currentDateTimeUtc().toString(
-	        Utility::dateTimeFileSuffixFormat);
-}
-
 enum WriteFileState confFileFixBackSlashes(const QString &filePath,
     bool useAux)
 {
