@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 #include <QSqlQuery>
 
 #include "src/datovka_shared/compat/compiler.h" /* macroStdMove */
-#include "src/io/filesystem.h"
+#include "src/datovka_shared/io/filesystem.h"
 #include "src/io/message_db_set.h"
 
 bool MessageDbSet::vacuum(void)
