@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,12 +36,12 @@
 #include "src/datovka_shared/compat_qt/variant.h" /* nullVariantWhenIsNull */
 #include "src/datovka_shared/graphics/colour.h"
 #include "src/datovka_shared/identifiers/account_id.h"
+#include "src/datovka_shared/io/db_helper.h"
 #include "src/datovka_shared/json/basic.h"
+#include "src/datovka_shared/json/db_info.h"
 #include "src/datovka_shared/log/log.h"
-#include "src/io/db_helper.h"
 #include "src/io/tag_db.h"
 #include "src/io/tag_db_tables.h"
-#include "src/json/db_info.h"
 #include "src/json/message_id.h"
 #include "src/json/tag_assignment.h"
 #include "src/json/tag_assignment_hash.h"
