@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,18 +29,27 @@
 #include "src/datovka_shared/compat/compiler.h" /* macroStdMove */
 #include "src/datovka_shared/compat_qt/variant.h" /* nullVariantWhenIsNull */
 #include "src/datovka_shared/identifiers/account_id.h"
+#include "src/datovka_shared/io/db_helper.h"
+#include "src/datovka_shared/io/db_time.h"
 #include "src/datovka_shared/isds/type_conversion.h" /* Isds::variant2NilBool */
+#include "src/datovka_shared/json/db_info.h"
 #include "src/datovka_shared/log/log.h"
-#include "src/io/db_helper.h"
-#include "src/io/dbs.h"
 #include "src/io/timestamp_db.h"
 #include "src/io/timestamp_db_tables.h"
-#include "src/json/db_info.h"
 
 /* Current database version. */
 #define DB_VER_MAJOR 1
 #define DB_VER_MINOR 0
 
+void TstValidityHash::declareTypes(void)
+{
+	/*
+	 * Calling qRegisterMetaType() is required for queued signal and slot
+	 * connections.
+	 */
+	qRegisterMetaType<TstValidityHash>("TstValidityHash");
+}
+
 enum ErrorCode {
 	EC_OK = 0, /*!< Operation succeeded. */
 	EC_INPUT, /*!< Invalid input supplied. */
@@ -134,7 +143,7 @@ fail:
  *
  * @param[in,out] query SQL query to work with.
  * @param[in] acntId Account identifier.
- * @param[out] key Primary key if the corresponding entry.
+ * @param[out] key Primary key of the corresponding entry.
  * @return Error code.
  */
 static
@@ -437,8 +446,6 @@ success:
  * @brief Constructs a string containing a comma-separated list
  *     of numeric identifiers.
  *
- * @note This function doesn't lock the database lock.
- *
  * @param[in] ids List of numeric identifiers.
  * @return String with list or empty string when \a ids empty or on failure.
  */
@@ -463,8 +470,6 @@ QString toListString(const QList<qint64> &ids)
  * @brief Construct a condition expression from supplied identifiers for matching
  *     testEnv and dmId pairs -- delivery time values are ignored.
  *
- * @note This function doesn't lock the database lock.
- *
  * @param[in] msgIds Message/delivery info identifiers.
  * @return String with condition expression or empty string when \a msgIds empty or on failure.
  */
@@ -492,8 +497,6 @@ QString toConditionExpr1(const Json::MsgId1List &msgIds)
  * @brief Construct a condition expression from supplied identifiers for matching
  *     testEnv and dmId pairs -- delivery time values are ignored.
  *
- * @note This function doesn't lock the database lock.
- *
  * @param[in] msgIds Message/delivery info identifiers.
  * @return String with condition expression or empty string when \a msgIds empty or on failure.
  */
@@ -819,7 +822,7 @@ success:
  * @return Error code.
  */
 static
-enum ErrorCode _tabDbInfoEntryCount(const QSqlDatabase &db,
+enum ErrorCode _tabEntryCount(const QSqlDatabase &db,
     class SQLiteTbl &table, qint64 &cnt)
 {
 	QSqlQuery query(db);
@@ -869,7 +872,7 @@ bool TimestampDb::getIdentificationCnt(qint64 &cnt) const
 	QMutexLocker locker(&m_lock);
 
 	qint64 readVal = 0;
-	ec = _tabDbInfoEntryCount(m_db, TimestampDbTables::identificationTbl,
+	ec = _tabEntryCount(m_db, TimestampDbTables::identificationTbl,
 	    readVal);
 	if (Q_UNLIKELY(ec != EC_OK)) {
 		cnt = 0;
@@ -1294,7 +1297,7 @@ bool TimestampDb::assureConsistency(void)
 	{
 		enum ErrorCode ec = EC_OK;
 		qint64 entryCount = 0;
-		ec = _tabDbInfoEntryCount(m_db, TimestampDbTables::_dbInfoTbl,
+		ec = _tabEntryCount(m_db, TimestampDbTables::_dbInfoTbl,
 		    entryCount);
 		if (Q_UNLIKELY(ec != EC_OK)) {
 			ret = false;
