@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,28 +25,32 @@
 #include <QCryptographicHash>
 #include <QDir>
 #include <QFileInfo>
+#include <QMutexLocker>
 #include <QNetworkAccessManager>
 #include <QNetworkReply>
 #include <QRegularExpression>
 
-#include "src/about.h"
 #include "src/common.h"
+#include "src/datovka_shared/app_version_info.h"
 #include "src/datovka_shared/compat_qt/misc.h"
+#include "src/datovka_shared/io/filesystem.h"
 #include "src/datovka_shared/log/log.h"
 #include "src/io/filesystem.h"
 #include "src/io/update_checker.h"
 #include "src/settings/prefs_specific.h"
 #include "src/settings/proxy.h"
-#include "src/settings/system_detection.h"
 
 UpdateChecker::UpdateChecker(Prefs &prefs, ProxiesSettings &proxies,
     QObject *parent)
     : QObject(parent),
+    m_lock(),
     m_prefs(prefs),
     m_proxies(proxies),
-    m_latestCheckTime(),
+    m_latestCheckAttemptTime(),
+    m_latestSuccessfulCheckTime(),
     m_newestVersion(),
     m_csv(),
+    m_downloadedPkgType(SysDetect::PKG_UNKNOWN),
     m_state(STATE_IDLE),
     m_versionFoundEmitted(false),
     m_packageDownloadAttempt(0),
@@ -91,14 +95,17 @@ UpdateChecker::~UpdateChecker(void)
 	}
 }
 
-bool UpdateChecker::startVersionCheck(int cooldownSecs)
+bool UpdateChecker::startVersionCheck(int cooldownSecs,
+    enum SysDetect::PkgType preferredPkgType)
 {
+	QMutexLocker locker(&m_lock);
+
 	const QDateTime currentDateTime = QDateTime::currentDateTime().toUTC();
 
 	if ((cooldownSecs > 0) &&
 	    (!m_newestVersion.isEmpty()) && (!m_csv.isEmpty()) &&
-	    m_latestCheckTime.isValid() &&
-	    (m_latestCheckTime.secsTo(currentDateTime) <= cooldownSecs)) {
+	    m_latestCheckAttemptTime.isValid() &&
+	    (m_latestCheckAttemptTime.secsTo(currentDateTime) <= cooldownSecs)) {
 		/* Don't perform checks if on cool down. */
 		return false;
 	}
@@ -108,14 +115,36 @@ bool UpdateChecker::startVersionCheck(int cooldownSecs)
 		return false;
 	}
 
+	m_latestCheckAttemptTime = currentDateTime;
+
 	m_packageDownloadAttempt = 0;
 
 	QUrl verUrl(DATOVKA_CHECK_NEW_VERSION_URL);
 	QUrl csvUrl(DATOVKA_PACKAGE_LIST_FILE_URL);
 
-	if (m_state != STATE_DOWNLOADING_VERSION) {
+	const enum SysDetect::PkgType detectedPkgType = SysDetect::detectPackageType();
+
+	/*
+	 * It is unsafe to start a version check when a previous one might be
+	 * in progress.
+	 */
+	switch (m_state) {
+	case STATE_IDLE:
+	case STATE_HAVE_PACKAGE:
+		m_downloadedPkgType = detectedPkgType;
+
+		/* Allow preferred package type if allowed. */
+		if ((SysDetect::PKG_UNKNOWN != preferredPkgType)
+		    && allowPackageTypeChange(detectedPkgType, preferredPkgType)) {
+			m_downloadedPkgType = preferredPkgType;
+		}
+
 		m_state = STATE_DOWNLOADING_VERSION;
 		emit stateChanged(m_state);
+		break;
+	default:
+		return false;
+		break;
 	}
 	m_verRep = m_nam->get(QNetworkRequest(verUrl));
 	m_cvsRep = m_nam->get(QNetworkRequest(csvUrl));
@@ -219,7 +248,7 @@ QString UpdateChecker::newestVersion(void) const
 bool UpdateChecker::newerVersionAvailable(void) const
 {
 	return (!m_newestVersion.isEmpty()) &&
-	    (1 == compareVersionStrings(m_newestVersion,
+	    (1 == AppVersionInfo::compareVersionStrings(m_newestVersion,
 	         QCoreApplication::applicationVersion()));
 }
 
@@ -288,8 +317,7 @@ QString UpdateChecker::packageUrl(void) const
 		return QString();
 	}
 
-	const enum SysDetect::PkgType pkgType = SysDetect::detectPackageType();
-	switch (pkgType) {
+	switch (m_downloadedPkgType) {
 	case SysDetect::PKG_UNKNOWN:
 		/* There is nothing to be downloaded. */
 		logWarningNL("%s", "Could not detect package type.");
@@ -306,10 +334,10 @@ QString UpdateChecker::packageUrl(void) const
 		break;
 	}
 
-	const QString &csvPrefStr = csvPrefix(pkgType);
+	const QString &csvPrefStr = csvPrefix(m_downloadedPkgType);
 
 	QStringList csvLines = m_csv.split('\n');
-	foreach (const QString &line, csvLines) {
+	for (const QString &line : csvLines) {
 		const QStringList entries = line.split(',');
 		if (entries.size() < 2) {
 			continue;
@@ -356,7 +384,8 @@ bool checkFileSha256Sum(const QString &filePath, const QString &sha256sum)
 	return hash.result().toHex() == sha256sum.toLower();
 }
 
-QString UpdateChecker::downloadedPackagePath(void) const
+QString UpdateChecker::downloadedPackagePath(
+    enum SysDetect::PkgType *downloadedPkgType) const
 {
 	if (m_newestVersion.isEmpty()) {
 		return QString();
@@ -367,6 +396,9 @@ QString UpdateChecker::downloadedPackagePath(void) const
 		    PrefsSpecific::downloadedPkgVersion(m_prefs);
 		if (downloadedPkgVersion != m_newestVersion) {
 			/* Downloaded package version doesn't match. */
+			if (Q_NULLPTR != downloadedPkgType) {
+				*downloadedPkgType = SysDetect::PKG_UNKNOWN;
+			}
 			return QString();
 		}
 	}
@@ -376,12 +408,18 @@ QString UpdateChecker::downloadedPackagePath(void) const
 	if (downloadedPkgSha256.isEmpty()) {
 		logWarningNL("%s",
 		    "Cannot obtain downloaded package SHA256SUM.");
+		if (Q_NULLPTR != downloadedPkgType) {
+			*downloadedPkgType = SysDetect::PKG_UNKNOWN;
+		}
 		return QString();
 	}
 
 	QString downloadedPkgPath = PrefsSpecific::downloadedPkgPath(m_prefs);
 	if (downloadedPkgPath.isEmpty()) {
 		logErrorNL("%s", "Cannot obtain downloaded package file.");
+		if (Q_NULLPTR != downloadedPkgType) {
+			*downloadedPkgType = SysDetect::PKG_UNKNOWN;
+		}
 		return QString();
 	}
 
@@ -395,6 +433,9 @@ QString UpdateChecker::downloadedPackagePath(void) const
 			    "Download URL points to different file name '%s' than is the already downloaded one '%s'.",
 			    urlFileName.toUtf8().constData(),
 			    downloadedFileName.toUtf8().constData());
+			if (Q_NULLPTR != downloadedPkgType) {
+				*downloadedPkgType = SysDetect::PKG_UNKNOWN;
+			}
 			return QString();
 		}
 
@@ -402,6 +443,9 @@ QString UpdateChecker::downloadedPackagePath(void) const
 		    (!fileInfo.isReadable())) {
 			logErrorNL("Cannot access file '%s'.",
 			    downloadedPkgPath.toUtf8().constData());
+			if (Q_NULLPTR != downloadedPkgType) {
+				*downloadedPkgType = SysDetect::PKG_UNKNOWN;
+			}
 			return QString();
 		}
 	}
@@ -411,6 +455,9 @@ QString UpdateChecker::downloadedPackagePath(void) const
 		logErrorNL("File '%s' does not match the SHA256SUM '%s'.",
 		    downloadedPkgPath.toUtf8().constData(),
 		    downloadedPkgSha256.toUtf8().constData());
+		if (Q_NULLPTR != downloadedPkgType) {
+			*downloadedPkgType = SysDetect::PKG_UNKNOWN;
+		}
 		return QString();
 	}
 
@@ -420,9 +467,24 @@ QString UpdateChecker::downloadedPackagePath(void) const
 	    downloadedPkgSha256.toUtf8().constData(),
 	    m_newestVersion.toUtf8().constData());
 
+	if (Q_NULLPTR != downloadedPkgType) {
+		*downloadedPkgType = m_downloadedPkgType;
+	}
 	return downloadedPkgPath;
 }
 
+bool UpdateChecker::allowPackageTypeChange(enum SysDetect::PkgType fromPkgType,
+    enum SysDetect::PkgType toPkgType)
+{
+	if ((SysDetect::PKG_WIN32_PORTABLE == fromPkgType) &&
+	    (SysDetect::PKG_WIN64_PORTABLE == toPkgType)) {
+		/* Allow update from 32-bit portable to 64-bit portable. */
+		return true;
+	}
+
+	return false;
+}
+
 /*!
  * @brief Extract the version string from obtained network response data.
  *
@@ -452,7 +514,7 @@ static
 QString extractSha256Sum(const QByteArray &data, const QString &fileName)
 {
 	QStringList lines = QString::fromUtf8(data).split('\n');
-	foreach (const QString &line, lines) {
+	for (const QString &line : lines) {
 		const QStringList entries = line.split(' ', _Qt_SkipEmptyParts);
 		if (entries.size() < 2) {
 			continue;
@@ -513,12 +575,12 @@ void UpdateChecker::processNetworkReply(QNetworkReply *reply)
 			m_newestVersion = extractVersionString(reply->readAll());
 			m_verRep = Q_NULLPTR;
 
-			m_latestCheckTime = QDateTime::currentDateTime().toUTC();
+			m_latestSuccessfulCheckTime = QDateTime::currentDateTime().toUTC();
 		} else if (reply == m_cvsRep) {
 			m_csv = QString::fromUtf8(reply->readAll());
 			m_cvsRep = Q_NULLPTR;
 
-			m_latestCheckTime = QDateTime::currentDateTime().toUTC();
+			m_latestSuccessfulCheckTime = QDateTime::currentDateTime().toUTC();
 		} else if (reply == m_sha256Rep) {
 			PrefsSpecific::setDownloadedPkgSha256Sum(m_prefs,
 			    extractSha256Sum(reply->readAll(), urlFileName(packageUrl())));
@@ -558,7 +620,7 @@ void UpdateChecker::processNetworkReply(QNetworkReply *reply)
 	}
 
 	if (m_newestVersion.isEmpty() && m_csv.isEmpty()) {
-		m_latestCheckTime = QDateTime();
+		m_latestSuccessfulCheckTime = QDateTime();
 	}
 
 	/* Determine new state. */
