@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -66,17 +66,12 @@ enum Isds::Type::RawType Isds::libisdsRawType2RawType(int irt, bool *ok)
 	return type;
 }
 
-/*!
- * @brief Converts user types.
- */
-static
-Isds::Type::HashAlg libisdsHashAlg2HashAlg(isds_hash_algorithm a,
-    bool *ok = Q_NULLPTR)
+Isds::Type::HashAlg Isds::libisdsHashAlg2HashAlg(int iha, bool *ok)
 {
 	bool iOk = true;
 	enum Isds::Type::HashAlg alg = Isds::Type::HA_UNKNOWN;
 
-	switch (a) {
+	switch (iha) {
 	case HASH_ALGORITHM_MD5: alg = Isds::Type::HA_MD5; break;
 	case HASH_ALGORITHM_SHA_1: alg = Isds::Type::HA_SHA_1; break;
 	case HASH_ALGORITHM_SHA_224: alg = Isds::Type::HA_SHA_224; break;
@@ -95,6 +90,30 @@ Isds::Type::HashAlg libisdsHashAlg2HashAlg(isds_hash_algorithm a,
 	return alg;
 }
 
+int Isds::hashAlg2libisdsHashAlg(enum Isds::Type::HashAlg ha, bool *ok)
+{
+	bool iOk = true;
+	isds_hash_algorithm alg = HASH_ALGORITHM_MD5; /* TODO -- This value is clearly incorrect. */
+
+	switch (ha) {
+	case Isds::Type::HA_MD5: alg = HASH_ALGORITHM_MD5; break;
+	case Isds::Type::HA_SHA_1: alg = HASH_ALGORITHM_SHA_1; break;
+	case Isds::Type::HA_SHA_224: alg = HASH_ALGORITHM_SHA_224; break;
+	case Isds::Type::HA_SHA_256: alg = HASH_ALGORITHM_SHA_256; break;
+	case Isds::Type::HA_SHA_384: alg = HASH_ALGORITHM_SHA_384; break;
+	case Isds::Type::HA_SHA_512: alg = HASH_ALGORITHM_SHA_512; break;
+	default:
+		Q_ASSERT(0);
+		iOk = false;
+		break;
+	}
+
+	if (ok != Q_NULLPTR) {
+		*ok = iOk;
+	}
+	return alg;
+}
+
 /*!
  * @brief Set hash according to isds_hash structure.
  */
@@ -107,7 +126,7 @@ bool setHashContent(Isds::Hash &tgt, const struct isds_hash *src)
 
 	bool iOk = false;
 
-	tgt.setAlgorithm(libisdsHashAlg2HashAlg(src->algorithm, &iOk));
+	tgt.setAlgorithm(Isds::libisdsHashAlg2HashAlg(src->algorithm, &iOk));
 	if (Q_UNLIKELY(!iOk)) {
 		tgt.setValue(QByteArray());
 		return false;
@@ -132,35 +151,6 @@ Isds::Hash Isds::libisds2hash(const struct isds_hash *ih, bool *ok)
 	return hash;
 }
 
-/*!
- * @brief Converts user types.
- */
-static
-isds_hash_algorithm hashAlg2libisdsHashAlg(Isds::Type::HashAlg a,
-    bool *ok = Q_NULLPTR)
-{
-	bool iOk = true;
-	isds_hash_algorithm alg = HASH_ALGORITHM_MD5; /* TODO -- This value is clearly incorrect. */
-
-	switch (a) {
-	case Isds::Type::HA_MD5: alg = HASH_ALGORITHM_MD5; break;
-	case Isds::Type::HA_SHA_1: alg = HASH_ALGORITHM_SHA_1; break;
-	case Isds::Type::HA_SHA_224: alg = HASH_ALGORITHM_SHA_224; break;
-	case Isds::Type::HA_SHA_256: alg = HASH_ALGORITHM_SHA_256; break;
-	case Isds::Type::HA_SHA_384: alg = HASH_ALGORITHM_SHA_384; break;
-	case Isds::Type::HA_SHA_512: alg = HASH_ALGORITHM_SHA_512; break;
-	default:
-		Q_ASSERT(0);
-		iOk = false;
-		break;
-	}
-
-	if (ok != Q_NULLPTR) {
-		*ok = iOk;
-	}
-	return alg;
-}
-
 /*!
  * @brief Set isds_hash structure according to the hash.
  */
@@ -174,7 +164,7 @@ bool setLibisdsHashContent(struct isds_hash *tgt, const Isds::Hash &src)
 
 	bool iOk = false;
 
-	tgt->algorithm = hashAlg2libisdsHashAlg(src.algorithm(), &iOk);
+	tgt->algorithm = (isds_hash_algorithm)Isds::hashAlg2libisdsHashAlg(src.algorithm(), &iOk);
 	if (Q_UNLIKELY(!iOk)) {
 		return false;
 	}
