@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -55,6 +55,26 @@ namespace Isds {
 	 */
 	enum Type::RawType guessFileRawType(const QString &fName);
 
+	/*!
+	 * @brief Guess type of data.
+	 *
+	 * @param[in] rawMsgData Raw ZFO data.
+	 * @param[out] attachTotal Total of attachment sizes.
+	 * @return ZFO data type, RT_UNKNOWN on any error.
+	 */
+	enum Type::RawType guessDataRawTypeAttachTotal(
+	    const QByteArray &rawMsgData, qint64 &attachTotal);
+
+	/*!
+	 * @brief Guess type of data in file.
+	 *
+	 * @param[in] fName File name.
+	 * @param[out] attachTotal Total of attachment sizes.
+	 * @return ZFO data type, RT_UNKNOWN on any error.
+	 */
+	enum Type::RawType guessFileRawTypeAttachTotal(const QString &fName,
+	    qint64 &attachTotal);
+
 	/*!
 	 * @brief Creates a message from supplied raw CMS data.
 	 *
@@ -96,4 +116,14 @@ namespace Isds {
 	Message parseZfoFile(const QString &fName,
 	    enum LoadType &zfoType, bool *ok = Q_NULLPTR);
 
+	/*!
+	 * @brief Compute message hash.
+	 *
+	 * @param[in] message Message.
+	 * @param[in] hashAlg Hash algorithm to be used.
+	 * @retunr Computed hash.
+	 */
+	Hash computeDmHash(const Message &message,
+	    enum Type::HashAlg hashAlg);
+
 }
