@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,9 +36,9 @@
 #include "src/cli/cli_parser.h"
 #include "src/cli/cli_pin.h"
 #include "src/cli/cmd_compose.h"
-#include "src/crypto/crypto_funcs.h"
-#include "src/crypto/crypto_threads.h"
 #include "src/datovka_shared/compat_qt/random.h"
+#include "src/datovka_shared/crypto/crypto_funcs.h"
+#include "src/datovka_shared/crypto/crypto_threads.h"
 #include "src/datovka_shared/crypto/crypto_version.h"
 #include "src/datovka_shared/io/db_tables.h"
 #include "src/datovka_shared/io/sqlite/db.h"
