@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -189,10 +189,11 @@ int AccountModel::rowCount(const QModelIndex &parent) const
 
 	switch (nodeType(parent)) {
 	case nodeAccountTop:
-		rows = 3;
+		rows = 4;
 		break;
 	case nodeRecentReceived:
 	case nodeRecentSent:
+	case nodeDrafts:
 		rows = 0;
 		break;
 	case nodeAll:
@@ -279,6 +280,20 @@ QVariant AccountModel::data(const QModelIndex &index, int role) const
 		case nodeRecentSent:
 			return tr("Recent Sent");
 			break;
+		case nodeDrafts:
+			{
+				QString label(tr("Drafts"));
+				Q_ASSERT(m_countersMap.constFind(aId) !=
+				    m_countersMap.constEnd());
+				const AccountCounters &cntrs(
+				    m_countersMap[aId]);
+				if (cntrs.drafts > 0) {
+					label += QString(" (%1)").arg(
+					    cntrs.drafts);
+				}
+				return label;
+			}
+			break;
 		case nodeAll:
 			return tr("All");
 			break;
@@ -353,6 +368,9 @@ QVariant AccountModel::data(const QModelIndex &index, int role) const
 			case nodeSentYear:
 				return inconContainer.icon(IconContainer::ICON_MESSAGE_SENT);
 				break;
+			case nodeDrafts:
+				return inconContainer.icon(IconContainer::ICON_APP_PENCIL);
+				break;
 			default:
 				return QVariant();
 				break;
@@ -464,6 +482,20 @@ QVariant AccountModel::data(const QModelIndex &index, int role) const
 		case nodeRecentSent:
 			return tr("recently sent messages");
 			break;
+		case nodeDrafts:
+			{
+				QString label(tr("messages saved as drafts"));
+				Q_ASSERT(m_countersMap.constFind(aId) !=
+				    m_countersMap.constEnd());
+				const AccountCounters &cntrs(
+				    m_countersMap[aId]);
+				if (cntrs.drafts > 0) {
+					label += QLatin1String(" - ") +
+					    tr("holds %n drafts(s)", "", cntrs.drafts);
+				}
+				return label;
+			}
+			break;
 		case nodeAll:
 			return tr("all messages");
 			break;
@@ -606,9 +638,20 @@ Qt::ItemFlags AccountModel::flags(const QModelIndex &index) const
 	Qt::ItemFlags defaultFlags = QAbstractItemModel::flags(index);
 
 	if (index.isValid()) {
-		if (nodeAccountTop == nodeType(index)) {
+		switch (nodeType(index)) {
+		case nodeAccountTop:
 			/* Allow drags on account top entries. */
 			defaultFlags |= Qt::ItemIsDragEnabled;
+			break;
+		case nodeRecentReceived:
+		case nodeRecentSent:
+		case nodeDrafts:
+		case nodeReceivedYear:
+		case nodeSentYear:
+			defaultFlags |= Qt::ItemNeverHasChildren;
+			break;
+		default:
+			break;
 		}
 	} else {
 		defaultFlags |= Qt::ItemIsDropEnabled;
@@ -889,11 +932,11 @@ bool AccountModel::updateRecentUnread(const AcntId &acntId,
 	if (nodeRecentReceived == nodeType) {
 		unreadRecent = &cntrs.unreadRecentReceived;
 		/* Get recently received node. */
-		childIndex = index(0, 0, topIndex);
+		childIndex = index(CHROW_RECENT_RCVD, 0, topIndex);
 	} else if (nodeRecentSent == nodeType) {
 		unreadRecent = &cntrs.unreadRecentSent;
 		/* Get recently sent node. */
-		childIndex = index(1, 0, topIndex);
+		childIndex = index(CHROW_RECENT_SENT, 0, topIndex);
 	} else {
 		Q_ASSERT(0);
 		return false;
@@ -914,6 +957,31 @@ bool AccountModel::updateRecentUnread(const AcntId &acntId,
 	return true;
 }
 
+bool AccountModel::updateDraftCount(const AcntId &acntId, unsigned drafts)
+{
+	if (Q_UNLIKELY(!acntId.isValid())) {
+		Q_ASSERT(0);
+		return false;
+	}
+
+	const QModelIndex topIndex(topAcntIndex(acntId));
+	if (Q_UNLIKELY(!topIndex.isValid())) {
+		return false;
+	}
+
+	AccountCounters &cntrs(m_countersMap[acntId]);
+
+	if (cntrs.drafts != drafts) {
+		QModelIndex childIndex = index(CHROW_DRAFTS, 0, topIndex);
+
+		cntrs.drafts = drafts;
+
+		Q_EMIT dataChanged(childIndex, childIndex);
+	}
+
+	return true;
+}
+
 /*!
  * @brief Get position of the newly inserted year element.
  *
@@ -999,14 +1067,14 @@ bool AccountModel::updateYearNodes(const AcntId &acntId,
 			groups = &cntrs.receivedGroups;
 			unreadGroups = &cntrs.unreadReceivedGroups;
 			/* Get received node. */
-			childTopIndex = index(2, 0, topIndex);
-			childTopIndex = index(0, 0, childTopIndex);
+			childTopIndex = index(CHROW_ALL, 0, topIndex);
+			childTopIndex = index(CHROW_RCVD, 0, childTopIndex);
 		} else if (nodeSentYear == nodeType) {
 			groups = &cntrs.sentGroups;
 			unreadGroups = &cntrs.unreadSentGroups;
 			/* Get sent node. */
-			childTopIndex = index(2, 0, topIndex);
-			childTopIndex = index(1, 0, childTopIndex);
+			childTopIndex = index(CHROW_ALL, 0, topIndex);
+			childTopIndex = index(CHROW_SENT, 0, childTopIndex);
 		} else {
 			Q_ASSERT(0);
 			return false;
@@ -1090,14 +1158,14 @@ bool AccountModel::updateYear(const AcntId &acntId,
 		groups = &cntrs.receivedGroups;
 		unreadGroups = &cntrs.unreadReceivedGroups;
 		/* Get received node. */
-		childIndex = index(2, 0, topIndex);
-		childIndex = index(0, 0, childIndex);
+		childIndex = index(CHROW_ALL, 0, topIndex); //
+		childIndex = index(CHROW_RCVD, 0, childIndex);
 	} else if (nodeSentYear == nodeType) {
 		groups = &cntrs.sentGroups;
 		unreadGroups = &cntrs.unreadSentGroups;
 		/* Get sent node. */
-		childIndex = index(2, 0, topIndex);
-		childIndex = index(1, 0, childIndex);
+		childIndex = index(CHROW_ALL, 0, topIndex);
+		childIndex = index(CHROW_SENT, 0, childIndex);
 	} else {
 		Q_ASSERT(0);
 		return false;
@@ -1284,8 +1352,8 @@ void AccountModel::removeYearNodes(const QModelIndex &topIndex)
 	AccountCounters &cntrs(m_countersMap[aId]);
 
 	/* Received. */
-	QModelIndex childTopIndex = index(2, 0, topIndex);
-	childTopIndex = index(0, 0, childTopIndex);
+	QModelIndex childTopIndex = index(CHROW_ALL, 0, topIndex);
+	childTopIndex = index(CHROW_RCVD, 0, childTopIndex);
 	int rows = rowCount(childTopIndex);
 	if (rows > 0) {
 		beginRemoveRows(childTopIndex, 0, rows - 1);
@@ -1295,8 +1363,8 @@ void AccountModel::removeYearNodes(const QModelIndex &topIndex)
 	}
 
 	/* Sent. */
-	childTopIndex = index(2, 0, topIndex);
-	childTopIndex = index(1, 0, childTopIndex);
+	childTopIndex = index(CHROW_ALL, 0, topIndex);
+	childTopIndex = index(CHROW_SENT, 0, childTopIndex);
 	rows = rowCount(childTopIndex);
 	if (rows > 0) {
 		beginRemoveRows(childTopIndex, 0, rows - 1);
@@ -1318,13 +1386,16 @@ enum AccountModel::NodeType AccountModel::childNodeType(
 		break;
 	case nodeAccountTop:
 		switch (childRow) {
-		case 0:
+		case CHROW_RECENT_RCVD:
 			return nodeRecentReceived;
 			break;
-		case 1:
+		case CHROW_RECENT_SENT:
 			return nodeRecentSent;
 			break;
-		case 2:
+		case CHROW_DRAFTS:
+			return nodeDrafts;
+			break;
+		case CHROW_ALL:
 			return nodeAll;
 			break;
 		default:
@@ -1334,14 +1405,15 @@ enum AccountModel::NodeType AccountModel::childNodeType(
 		break;
 	case nodeRecentReceived:
 	case nodeRecentSent:
+	case nodeDrafts:
 		return nodeUnknown;
 		break;
 	case nodeAll:
 		switch (childRow) {
-		case 0:
+		case CHROW_RCVD:
 			return nodeReceived;
 			break;
-		case 1:
+		case CHROW_SENT:
 			return nodeSent;
 			break;
 		default:
@@ -1373,47 +1445,48 @@ enum AccountModel::NodeType AccountModel::parentNodeType(
 	case nodeUnknown:
 	case nodeRoot:
 		if (Q_NULLPTR != parentRow) {
-			*parentRow = -1;
+			*parentRow = CHROW_NONE;
 		}
 		return nodeUnknown;
 		break;
 	case nodeAccountTop:
 		if (Q_NULLPTR != parentRow) {
-			*parentRow = -1;
+			*parentRow = CHROW_ROOT;
 		}
 		return nodeRoot;
 		break;
 	case nodeRecentReceived:
 	case nodeRecentSent:
+	case nodeDrafts:
 	case nodeAll:
 		if (Q_NULLPTR != parentRow) {
-			*parentRow = -1;
+			*parentRow = CHROW_ACNT_TOP;
 		}
 		return nodeAccountTop;
 		break;
 	case nodeReceived:
 	case nodeSent:
 		if (Q_NULLPTR != parentRow) {
-			*parentRow = 2;
+			*parentRow = CHROW_ALL;
 		}
 		return nodeAll;
 		break;
 	case nodeReceivedYear:
 		if (Q_NULLPTR != parentRow) {
-			*parentRow = 0;
+			*parentRow = CHROW_RCVD;
 		}
 		return nodeReceived;
 		break;
 	case nodeSentYear:
 		if (Q_NULLPTR != parentRow) {
-			*parentRow = 1;
+			*parentRow = CHROW_SENT;
 		}
 		return nodeSent;
 		break;
 	default:
 		Q_ASSERT(0);
 		if (Q_NULLPTR != parentRow) {
-			*parentRow = -1;
+			*parentRow = CHROW_NONE;
 		}
 		return nodeUnknown;
 		break;
