@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -63,6 +63,26 @@ public:
 	Q_ENUMS(UserRoles)
 #endif /* >= Qt-5.5 */
 
+	/*!
+	 * @brief Position in row relative to their parents.
+	 */
+	enum ChildRows {
+		CHROW_NONE = -1, /*!< Convenience value. */
+		CHROW_ROOT = -1, /*!< Has no root. */
+		CHROW_ACNT_TOP = -1, /*!< Depends on ordering, no fixed position. */
+		CHROW_RECENT_RCVD = 0, /*!< 1st child of nodeAccountTop */
+		CHROW_RECENT_SENT = 1, /*!< 2nd child of nodeAccountTop */
+		CHROW_DRAFTS = 2, /*!< 3rd child of nodeAccountTop */
+		CHROW_ALL = 3, /*!< 4rd child of nodeAccountTop */
+		CHROW_RCVD = 0, /*!< 1st child of nodeAll */
+		CHROW_SENT = 1 /*!< 2nd child of nodeAll */
+	};
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 5, 0))
+	Q_ENUM(ChildRows)
+#else /* < Qt-5.5 */
+	Q_ENUMS(ChildRows)
+#endif /* >= Qt-5.5 */
+
 	/*
 	 * nodeRoot (Invisible.)
 	 * |
@@ -70,6 +90,7 @@ public:
 	 * |  |
 	 * |  +- nodeRecentReceived
 	 * |  +- nodeRecentSent
+	 * |  +- nodeDrafts
 	 * |  +- nodeAll
 	 * |     |
 	 * |     +- nodeReceived
@@ -102,6 +123,7 @@ public:
 		nodeAccountTop,
 		nodeRecentReceived,
 		nodeRecentSent,
+		nodeDrafts,
 		nodeAll,
 		nodeReceived,
 		nodeSent,
@@ -377,6 +399,15 @@ public:
 	bool updateRecentUnread(const AcntId &acntId,
 	    enum NodeType nodeType, unsigned unreadMsgs = 0);
 
+	/*!
+	 * @brief Set number of drafts in model nodes.
+	 *
+	 * @param[in] acntId Account identifier.
+	 * @param[in] drafts Number of drafts.
+	 * @return True on success.
+	 */
+	bool updateDraftCount(const AcntId &acntId, unsigned drafts);
+
 	/*!
 	 * @brief Update year nodes.
 	 *
@@ -516,7 +547,7 @@ private:
 		 * @brief Constructor.
 		 */
 		AccountCounters(void)
-		    : unreadRecentReceived(0), unreadRecentSent(0),
+		    : unreadRecentReceived(0), unreadRecentSent(0), drafts(0),
 		    receivedGroups(), sentGroups(),
 		    unreadReceivedGroups(), unreadSentGroups()
 		{
@@ -524,6 +555,7 @@ private:
 
 		unsigned unreadRecentReceived; /*!< Number of unread recent received messages. */
 		unsigned unreadRecentSent; /*!< Number of unread recent sent messages. */
+		unsigned drafts; /*!< Number of drafts. */
 		QList<QString> receivedGroups; /*!< Groups of unread messages. */
 		QList<QString> sentGroups; /*!< Groups of unread messages. */
 		QMap<QString, YearCounter> unreadReceivedGroups; /*< Number of unread messages. */
