@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,11 +32,12 @@
 #include <QUrl>
 
 #include "src/datovka_shared/compat/compiler.h" /* macroStdMove */
+#include "src/datovka_shared/io/filesystem.h"
+#include "src/datovka_shared/io/message_db_tables.h"
 #include "src/datovka_shared/isds/message_attachment.h"
 #include "src/datovka_shared/log/log.h"
 #include "src/io/filesystem.h"
 #include "src/io/message_db.h"
-#include "src/io/message_db_tables.h"
 #include "src/models/attachments_model.h"
 
 #define LOCAL_DATABASE_STR QStringLiteral("local database")
@@ -243,6 +244,9 @@ QVariant AttachmentTblModel::data(const QModelIndex &index, int role) const
 				    tr("local database") : QDir::toNativeSeparators(fPath);
 			}
 			break;
+		case CREATED_FROM_TEXT_COL:
+			return _data(index).toBool() ? tr("created from text message") : QVariant();
+			break;
 		default:
 			return _data(index, role);
 			break;
@@ -288,6 +292,7 @@ QVariant AttachmentTblModel::data(const QModelIndex &index, int role) const
 			break;
 		case MIME_COL:
 		case FPATH_COL:
+		case CREATED_FROM_TEXT_COL:
 			return headerData(index.column(), Qt::Horizontal).toString() +
 			    QStringLiteral(" ") + data(index).toString();
 			break;
@@ -303,21 +308,30 @@ QVariant AttachmentTblModel::data(const QModelIndex &index, int role) const
 		break;
 	case ROLE_PLAIN_DISPLAY:
 		/* Explicitly asking associated file path. */
-		if (index.column() == FPATH_COL) {
-			const QString fPath(_data(index.row(), FPATH_COL,
-			    Qt::DisplayRole).toString());
-			const QByteArray binaryData(_data(index.row(),
-			    BINARY_CONTENT_COL, Qt::DisplayRole).toByteArray());
+		switch (index.column()) {
+		case FPATH_COL:
+			{
+				const QString fPath(_data(index.row(), FPATH_COL,
+				    Qt::DisplayRole).toString());
+				const QByteArray binaryData(_data(index.row(),
+				    BINARY_CONTENT_COL, Qt::DisplayRole).toByteArray());
 
-			if ((fPath == LOCAL_DATABASE_STR) && !binaryData.isEmpty()) {
-				return QVariant(); /* No file present. */
-			} else if (fileReadable(fPath)) {
-				return fPath; /* File present. */
-			} else {
-				return QVariant();
+				if ((fPath == LOCAL_DATABASE_STR) && !binaryData.isEmpty()) {
+					return QVariant(); /* No file present. */
+				} else if (fileReadable(fPath)) {
+					return fPath; /* File present. */
+				} else {
+					return QVariant();
+				}
 			}
+			break;
+		case CREATED_FROM_TEXT_COL:
+			return _data(index).toBool();
+			break;
+		default:
+			return QVariant();
+			break;
 		}
-		return QVariant();
 		break;
 	default:
 		return _data(index, role);
@@ -629,7 +643,19 @@ QString mimeStr(const QString &fileName, const QByteArray &data)
 	return AttachmentTblModel::tr("unknown");
 }
 
-int AttachmentTblModel::insertAttachmentFile(const QString &filePath, int row)
+void AttachmentTblModel::removeAllCreatedFromText(void)
+{
+	/* In reverse. */
+	for (int row = rowCount() - 1; row >= 0; --row) {
+
+		if (_data(row, CREATED_FROM_TEXT_COL).toBool()) {
+			removeVector(row);
+		}
+	}
+}
+
+int AttachmentTblModel::insertAttachmentFile(const QString &filePath, int row,
+    bool createdFromText)
 {
 	if (Q_UNLIKELY(!fileExistent(filePath))) {
 		logWarningNL("Ignoring non-existent file '%s'.",
@@ -678,6 +704,7 @@ int AttachmentTblModel::insertAttachmentFile(const QString &filePath, int row)
 	rowVect[BINARY_SIZE_COL] = 0;
 #endif /* defined HOLD_FILE_CONTENT */
 	rowVect[FPATH_COL] = QDir::fromNativeSeparators(filePath);
+	rowVect[CREATED_FROM_TEXT_COL] = createdFromText;
 
 	/* Check data duplicity. */
 	if (insertVector(rowVect, row, true)) {
@@ -720,6 +747,7 @@ bool AttachmentTblModel::appendBinaryAttachment(const QByteArray &binaryContent,
 	rowVect[MIME_COL] = mimeStr(fName, binaryContent);
 	rowVect[BINARY_SIZE_COL] = binaryContent.size();
 	rowVect[FPATH_COL] = LOCAL_DATABASE_STR;
+	rowVect[CREATED_FROM_TEXT_COL] = false;
 
 	/* Check data duplicity. */
 	return insertVector(rowVect, rowCount(), true);
@@ -830,6 +858,22 @@ bool AttachmentTblModel::appendMessageData(const Isds::Message &message)
 	return true;
 }
 
+bool AttachmentTblModel::removeVector(int row)
+{
+	if (Q_UNLIKELY((row < 0) || (row > rowCount()))) {
+		return false;
+	}
+
+	beginRemoveRows(QModelIndex(), row, row);
+
+	m_data.remove(row, 1);
+	--m_rowCount;
+
+	endRemoveRows();
+
+	return true;
+}
+
 bool AttachmentTblModel::insertVector(const QVector<QVariant> &rowVect,
     int row, bool insertUnique)
 {
