@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,6 +26,8 @@
 
 #include "src/datovka_shared/compat/compiler.h" /* macroStdMove */
 #include "src/datovka_shared/graphics/graphics.h"
+#include "src/datovka_shared/io/db_time.h"
+#include "src/datovka_shared/io/message_db_tables.h"
 #include "src/datovka_shared/io/records_management_db.h"
 #include "src/datovka_shared/isds/type_conversion.h"
 #include "src/datovka_shared/isds/type_description.h"
@@ -35,9 +37,7 @@
 #include "src/delegates/tag_item.h"
 #include "src/global.h"
 #include "src/gui/icon_container.h"
-#include "src/io/dbs.h"
 #include "src/io/message_db.h"
-#include "src/io/message_db_tables.h"
 #include "src/io/timestamp_db.h" /* TstValidityHash */
 #include "src/json/message_id.h"
 #include "src/json/tag_assignment_hash.h"
