@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,6 +38,7 @@
 #include "src/gui/dlg_msg_box_detail.h"
 #include "src/gui/icon_container.h"
 #include "src/gui/message_operations.h" /* MsgOrigin */
+#include "src/gui/styles.h"
 #include "src/io/message_db_set_container.h"
 #include "src/io/message_db_set.h"
 #include "src/records_management/content/automatic_upload_target.h"
@@ -173,7 +174,7 @@ DlgRecordsManagementCheckMsgs::DlgRecordsManagementCheckMsgs(
 	/* Set table view model and properties. */
 	m_ui->accountTableView->setNarrowedLineHeight();
 	m_ui->accountTableView->horizontalHeader()->setDefaultAlignment(
-	    Qt::AlignLeft);
+	    Qt::AlignVCenter | Qt::AlignLeft);
 	m_ui->accountTableView->setSelectionMode(
 	    QAbstractItemView::ExtendedSelection);
 	m_ui->accountTableView->setSelectionBehavior(
@@ -181,7 +182,7 @@ DlgRecordsManagementCheckMsgs::DlgRecordsManagementCheckMsgs(
 
 	m_ui->msgTableView->setNarrowedLineHeight();
 	m_ui->msgTableView->horizontalHeader()->setDefaultAlignment(
-	    Qt::AlignLeft);
+	    Qt::AlignVCenter | Qt::AlignLeft);
 	m_ui->msgTableView->setSelectionMode(
 	    QAbstractItemView::ExtendedSelection);
 	m_ui->msgTableView->setSelectionBehavior(
@@ -289,6 +290,9 @@ DlgRecordsManagementCheckMsgs::DlgRecordsManagementCheckMsgs(
 		m_ui->toDateEdit->setMaximumDate(today);
 	}
 
+	GuiStyles::setCalendarStyle(m_ui->fromDateEdit->calendarWidget());
+	GuiStyles::setCalendarStyle(m_ui->toDateEdit->calendarWidget());
+
 	connect(m_ui->fromDateEdit, SIGNAL(dateChanged(QDate)),
 	    this, SLOT(reflectCalendarChange()));
 	connect(m_ui->toDateEdit, SIGNAL(dateChanged(QDate)),
@@ -1236,7 +1240,7 @@ void DlgRecordsManagementCheckMsgs::setupActions(void)
 	m_actionDownloadMessage = new (::std::nothrow) QAction(this);
 	if (m_actionDownloadMessage != Q_NULLPTR) {
 		m_actionDownloadMessage->setObjectName(QString::fromUtf8("actionDownloadMessage"));
-		m_actionDownloadMessage->setIcon(IconContainer::construcIcon(IconContainer::ICON_DATOVKA_MESSAGE_DOWNLOAD));
+		m_actionDownloadMessage->setIcon(IconContainer::construcIcon(IconContainer::ICON_MESSAGE_DOWNLOAD));
 		m_actionDownloadMessage->setMenuRole(QAction::NoRole);
 		m_actionDownloadMessage->setText(tr("Download Signed Message"));
 		m_actionDownloadMessage->setToolTip(tr("Download the complete message, i.e. including attachments, and verify its signature."));
@@ -1245,7 +1249,7 @@ void DlgRecordsManagementCheckMsgs::setupActions(void)
 	m_actionSendToRecordsManagement = new (::std::nothrow) QAction(this);
 	if (m_actionSendToRecordsManagement != Q_NULLPTR) {
 		m_actionSendToRecordsManagement->setObjectName(QString::fromUtf8("actionSendToRecordsManagement"));
-		m_actionSendToRecordsManagement->setIcon(IconContainer::construcIcon(IconContainer::ICON_BRIEFCASE));
+		m_actionSendToRecordsManagement->setIcon(IconContainer::construcIcon(IconContainer::ICON_BRIEFCASE_UPLOAD));
 		m_actionSendToRecordsManagement->setMenuRole(QAction::NoRole);
 		m_actionSendToRecordsManagement->setText(tr("Send to Records Management"));
 		m_actionSendToRecordsManagement->setToolTip(tr("Send message to records management service."));
