@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,6 +24,9 @@
 #include <QDir>
 #include <Qt> /* enum Qt::ToolButtonStyle */
 
+#include "src/common.h" /* ISDS_DOWNLOAD_TIMEOUT_MS */
+#include "src/datovka_shared/app_version_info.h"
+#include "src/datovka_shared/compat_qt/random.h"
 #include "src/datovka_shared/identifiers/account_id.h"
 #include "src/datovka_shared/json/basic.h"
 #include "src/datovka_shared/log/log.h"
@@ -166,18 +169,6 @@ void PrefsSpecific::setCheckNewVersions(Prefs &prefs, bool val)
 	prefs.setBoolVal("application.version.check.enabled", val);
 }
 
-bool PrefsSpecific::sendStatsWithVersionChecks(const Prefs &prefs)
-{
-	bool val = false;
-	return prefs.boolVal(
-	    "application.version.check.stats.send.enabled", val) && val;
-}
-
-void PrefsSpecific::setSendStatsWithVersionChecks(Prefs &prefs, bool val)
-{
-	prefs.setBoolVal("application.version.check.stats.send.enabled", val);
-}
-
 int PrefsSpecific::checkNewVersionsCooldown(const Prefs &prefs)
 {
 	qint64 val = 14400;
@@ -190,6 +181,35 @@ int PrefsSpecific::checkNewVersionsCooldown(const Prefs &prefs)
 	return val;
 }
 
+bool PrefsSpecific::isNewVersion(Prefs &prefs)
+{
+	bool isNew = true;
+	QString storedVersion;
+
+	/*
+	 * If running app doesn't have release version then don't check.
+	 */
+	if (Q_UNLIKELY(!AppVersionInfo::isReleaseVersionString(VERSION))) {
+		return false;
+	}
+
+	prefs.strVal("application.notification_shown.last_version", storedVersion);
+
+	/*
+	 * If stored version is empty or non-release version string then behave
+	 * as having a new version.
+	 */
+	isNew = storedVersion.isEmpty()
+	    || (!AppVersionInfo::isReleaseVersionString(storedVersion))
+	    || (1 == AppVersionInfo::compareVersionStrings(VERSION, storedVersion));
+
+	if (isNew) {
+		prefs.setStrVal("application.notification_shown.last_version", VERSION);
+	}
+
+	return isNew;
+}
+
 void PrefsSpecific::setCheckNewVersionsCooldown(Prefs &prefs, int val)
 {
 	if (val < 0) {
@@ -275,7 +295,7 @@ int PrefsSpecific::isdsDownloadTimeoutMs(const Prefs &prefs)
 	if (Q_UNLIKELY(!prefs.intVal("network.isds.communication.timeout.ms",
 	        val))) {
 		Q_ASSERT(0);
-		return 600000;
+		return ISDS_DOWNLOAD_TIMEOUT_MS;
 	}
 	return val;
 }
@@ -809,3 +829,291 @@ void PrefsSpecific::setMainWinTblColSortOrder(Prefs &prefs,
 		    Json::IntVector(val).toJsonData());
 	}
 }
+
+QDateTime PrefsSpecific::appFirstLaunchTime(const Prefs &prefs)
+{
+	QDateTime val;
+	if (Q_UNLIKELY(!prefs.dateTimeVal("stats.app.launch.first.datetime", val))) {
+		return QDateTime();
+	}
+	if (Q_UNLIKELY(!val.isValid())) {
+		return QDateTime();
+	}
+
+	return val;
+}
+
+void PrefsSpecific::storeAppFirstLaunchTime(Prefs &prefs)
+{
+	prefs.setDateTimeVal(
+	    "stats.app.launch.first.datetime", QDateTime::currentDateTime());
+}
+
+QDateTime PrefsSpecific::appLastLaunchTime(const Prefs &prefs)
+{
+	QDateTime val;
+	if (Q_UNLIKELY(!prefs.dateTimeVal("stats.app.launch.last.datetime", val))) {
+		return QDateTime();
+	}
+	if (Q_UNLIKELY(!val.isValid())) {
+		return QDateTime();
+	}
+
+	return val;
+}
+
+void PrefsSpecific::storeAppLastLaunchTime(Prefs &prefs)
+{
+	prefs.setDateTimeVal(
+	    "stats.app.launch.last.datetime", QDateTime::currentDateTime());
+}
+
+QDateTime PrefsSpecific::appPlannedDonationViewTime(const Prefs &prefs)
+{
+	QDateTime val;
+	if (Q_UNLIKELY(!prefs.dateTimeVal("stats.app.action.planned_donation_view.datetime", val))) {
+		return QDateTime();
+	}
+	if (Q_UNLIKELY(!val.isValid())) {
+		return QDateTime();
+	}
+
+	return val;
+}
+
+void PrefsSpecific::setAppPlannedDonationViewTime(Prefs &prefs,
+    const QDateTime &nextViewTime)
+{
+	prefs.setDateTimeVal(
+	    "stats.app.action.planned_donation_view.datetime", nextViewTime);
+}
+
+void PrefsSpecific::planNextDonationViewTime(Prefs &prefs, bool shortTime)
+{
+	int intervalDays = 0;
+
+	if (shortTime) {
+		/* Short Time Interval: 3 months, tolerance +- 15 days */
+		intervalDays = Compat::randBoundedInterval(75, 105);
+	} else {
+		/* Long Time Interval: 6 months, tolerance +- 30 days */
+		intervalDays = Compat::randBoundedInterval(150, 210);
+	}
+
+	setAppPlannedDonationViewTime(prefs,
+	    QDateTime::currentDateTimeUtc().addDays(intervalDays));
+}
+
+bool PrefsSpecific::isTimeToShowDonationDlg(Prefs &prefs)
+{
+	bool showDlg = false;
+	const QDateTime nextViewTime = appPlannedDonationViewTime(prefs);
+
+	if (Q_UNLIKELY(!nextViewTime.isValid())) {
+		planNextDonationViewTime(prefs, true);
+		return false;
+	}
+
+	showDlg = (nextViewTime < QDateTime::currentDateTimeUtc());
+	if (Q_UNLIKELY(showDlg)) {
+		planNextDonationViewTime(prefs, false);
+	}
+
+	return showDlg;
+}
+
+qint64 PrefsSpecific::appLaunchCount(const Prefs &prefs)
+{
+	qint64 val = -1;
+	if (Q_UNLIKELY(!prefs.intVal("stats.app.launch.count", val))) {
+		return -1;
+	}
+
+	return val;
+}
+
+void PrefsSpecific::incrementLaunchCount(Prefs &prefs)
+{
+	prefs.setIntVal("stats.app.launch.count", appLaunchCount(prefs) + 1);
+}
+
+QString PrefsSpecific::statsReportUniqueId(const Prefs &prefs)
+{
+	QString val;
+	prefs.strVal("stats.app.report.unique_id", val);
+	return val;
+}
+
+void PrefsSpecific::setStatsReportUniqueId(Prefs &prefs, const QString &val)
+{
+	prefs.setStrVal("stats.app.report.unique_id", val);
+}
+
+QDateTime PrefsSpecific::statsReportLastConsentRequest(const Prefs &prefs)
+{
+	QDateTime val;
+	if (Q_UNLIKELY(!prefs.dateTimeVal("stats.app.report.action.ask_consent.datetime", val))) {
+		return QDateTime();
+	}
+	if (Q_UNLIKELY(!val.isValid())) {
+		return QDateTime();
+	}
+
+	return val;
+}
+
+void PrefsSpecific::setStatsReportLastConsentRequest(Prefs &prefs,
+    const QDateTime &lastConsentDateTime)
+{
+	prefs.setDateTimeVal(
+	    "stats.app.report.action.ask_consent.datetime", lastConsentDateTime);
+}
+
+bool PrefsSpecific::statsReportUsage(const Prefs &prefs)
+{
+	bool val = false;
+	return prefs.boolVal(
+	    "stats.app.report.usage.send.enabled", val) && val;
+}
+
+void PrefsSpecific::setStatsReportUsage(Prefs &prefs, bool enabled)
+{
+	prefs.setBoolVal("stats.app.report.usage.send.enabled", enabled);
+}
+
+qint64 PrefsSpecific::appUiTheme(const Prefs &prefs)
+{
+	qint64 val = 0;
+	if (Q_UNLIKELY(!prefs.intVal(
+		"application.ui.theme", val))) {
+		return 0;
+	}
+	return val;
+}
+
+void PrefsSpecific::setAppUiTheme(Prefs &prefs, qint64 index)
+{
+	prefs.setIntVal("application.ui.theme", index);
+}
+
+qint64 PrefsSpecific::appUiThemeFontScalePercent(const Prefs &prefs)
+{
+	qint64 val = 100;
+	if (Q_UNLIKELY(!prefs.intVal(
+		"application.ui.theme.custom.font_scale.percent", val))) {
+		return 100;
+	}
+	return val;
+}
+
+void PrefsSpecific::setAppUiThemeFontScalePercent(Prefs &prefs, qint64 percent)
+{
+	prefs.setIntVal("application.ui.theme.custom.font_scale.percent", percent);
+}
+
+bool PrefsSpecific::autoBackupEnabled(const Prefs &prefs)
+{
+	bool val = false;
+	return prefs.boolVal("global.backup_notification.auto.enabled", val) && val;
+}
+
+void PrefsSpecific::setAutoBackupEnabled(Prefs &prefs, bool enabled)
+{
+	prefs.setBoolVal("global.backup_notification.auto.enabled", enabled);
+}
+
+QString PrefsSpecific::autoBackupPath(const Prefs &prefs)
+{
+	QString val;
+	prefs.strVal("global.backup_notification.auto.path", val);
+	return val;
+}
+
+void PrefsSpecific::setAutoBackupPath(Prefs &prefs, const QString &val)
+{
+	prefs.setStrVal("global.backup_notification.auto.path", val);
+}
+
+qint64 PrefsSpecific::autoBackupPeriodMonths(const Prefs &prefs)
+{
+	qint64 val = 3;
+	if (Q_UNLIKELY(!prefs.intVal(
+		"global.backup_notification.auto.period.months", val))) {
+		return 3;
+	}
+	return val;
+}
+
+void PrefsSpecific::setAutoBackupPeriodMonths(Prefs &prefs, qint64 months)
+{
+	prefs.setIntVal("global.backup_notification.auto.period.months", months);
+}
+
+QStringList PrefsSpecific::autoBackupSelected(const Prefs &prefs)
+{
+	QString strVal;
+	if (Q_UNLIKELY(!prefs.strVal(
+	        QStringLiteral("global.backup_notification.auto.databox.list.selected"),
+	        strVal))) {
+		return QStringList();
+	}
+	return Json::StringList::fromJsonStr(strVal.toUtf8());
+}
+
+void PrefsSpecific::setAutoBackupSelected(Prefs &prefs,
+    const QStringList &list)
+{
+	if (Q_UNLIKELY(list.isEmpty())) {
+		prefs.resetVal(QStringLiteral("global.backup_notification.auto.databox.list.selected"));
+	} else {
+		prefs.setStrVal(
+		    QStringLiteral("global.backup_notification.auto.databox.list.selected"),
+		    Json::StringList(list).toJsonData());
+	}
+}
+
+/*!
+ * @brief Get the value "global.backup_notification.auto.next.backup.datetime".
+ */
+static
+QDateTime autoBackupNextBackupDate(const Prefs &prefs)
+{
+	QDateTime val;
+	if (Q_UNLIKELY(!prefs.dateTimeVal("global.backup_notification.auto.next.backup.datetime",
+	        val))) {
+		return QDateTime();
+	}
+	if (Q_UNLIKELY(!val.isValid())) {
+		return QDateTime();
+	}
+	return val;
+}
+
+/*!
+ * @brief Set the value "global.backup_notification.auto.next.backup.datetime".
+ */
+static
+void setAutoBackupNextBackupDate(Prefs &prefs, const QDateTime &val)
+{
+	prefs.setDateTimeVal(
+	    "global.backup_notification.auto.next.backup.datetime", val);
+}
+
+bool PrefsSpecific::isTimeForAutoBackup(Prefs &prefs)
+{
+	const QDateTime nextBackupDate = autoBackupNextBackupDate(prefs);
+	if (Q_UNLIKELY(!nextBackupDate.isValid())) {
+		setAutoBackupNextBackupDate(prefs,
+		    QDateTime::currentDateTimeUtc().addMonths(
+		    autoBackupPeriodMonths(prefs)));
+		return true;
+	}
+
+	bool showDlg = (nextBackupDate < QDateTime::currentDateTimeUtc());
+	if (Q_UNLIKELY(showDlg)) {
+		setAutoBackupNextBackupDate(prefs,
+		    QDateTime::currentDateTimeUtc().addMonths(
+		    autoBackupPeriodMonths(prefs)));
+	}
+	return showDlg;
+}
