@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2026 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,8 +23,8 @@
 
 #include <QSettings>
 
+#include "src/datovka_shared/crypto/crypto_pin_wrapped.h"
 #include "src/datovka_shared/crypto/crypto_pwd.h"
-#include "src/datovka_shared/crypto/crypto_wrapped.h"
 #include "src/datovka_shared/log/log.h"
 #include "src/settings/tag_container_settings.h"
 
@@ -114,12 +114,14 @@ public:
 };
 
 TagContainerSettings::TagContainerSettings(void)
-    : d_ptr(Q_NULLPTR)
+    : QObject(),
+    d_ptr(Q_NULLPTR)
 {
 }
 
 TagContainerSettings::TagContainerSettings(const TagContainerSettings &other)
-    : d_ptr((other.d_func() != Q_NULLPTR) ? (new (::std::nothrow) TagContainerSettingsPrivate) : Q_NULLPTR)
+    : QObject(),
+    d_ptr((other.d_func() != Q_NULLPTR) ? (new (::std::nothrow) TagContainerSettingsPrivate) : Q_NULLPTR)
 {
 	Q_D(TagContainerSettings);
 	if (d == Q_NULLPTR) {
@@ -131,10 +133,11 @@ TagContainerSettings::TagContainerSettings(const TagContainerSettings &other)
 
 #ifdef Q_COMPILER_RVALUE_REFS
 TagContainerSettings::TagContainerSettings(TagContainerSettings &&other) Q_DECL_NOEXCEPT
+    : QObject(),
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 12, 0))
-    : d_ptr(other.d_ptr.release()) //d_ptr(::std::move(other.d_ptr))
+    d_ptr(other.d_ptr.release()) //d_ptr(::std::move(other.d_ptr))
 #else /* < Qt-5.12 */
-    : d_ptr(other.d_ptr.take())
+    d_ptr(other.d_ptr.take())
 #endif /* >= Qt-5.12 */
 {
 }
@@ -163,6 +166,8 @@ TagContainerSettings::~TagContainerSettings(void)
 
 TagContainerSettings &TagContainerSettings::operator=(const TagContainerSettings &other) Q_DECL_NOTHROW
 {
+	const bool different = (*this != other);
+
 	if (other.d_func() == Q_NULLPTR) {
 		d_ptr.reset(Q_NULLPTR);
 		return *this;
@@ -172,13 +177,24 @@ TagContainerSettings &TagContainerSettings::operator=(const TagContainerSettings
 
 	*d = *other.d_func();
 
+	if (different) {
+		Q_EMIT contentChanged();
+	}
+
 	return *this;
 }
 
 #ifdef Q_COMPILER_RVALUE_REFS
 TagContainerSettings &TagContainerSettings::operator=(TagContainerSettings &&other) Q_DECL_NOTHROW
 {
+	const bool different = (*this != other);
+
 	swap(*this, other);
+
+	if (different) {
+		Q_EMIT contentChanged();
+	}
+
 	return *this;
 }
 #endif /* Q_COMPILER_RVALUE_REFS */
